@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Kalendorius",
-    "Todos" : "Užduotys",
+    "Tasks" : "Užduotys",
     "Personal" : "Asmeniniai",
     "{actor} created calendar {calendar}" : "{actor} sukūrė kalendorių {calendar}",
     "You created calendar {calendar}" : "Jūs sukūrėte kalendorių {calendar}",
@@ -25,6 +25,7 @@ OC.L10N.register(
     "{actor} shared calendar {calendar} with group {group}" : "{actor} pradėjo bendrinti kalendorių {calendar} su grupe {group}",
     "You unshared calendar {calendar} from group {group}" : "Jūs nustojote bendrinti kalendorių {calendar} su grupe {group}",
     "{actor} unshared calendar {calendar} from group {group}" : "{actor} nustojo bendrinti kalendorių {calendar} su grupe {group}",
+    "Untitled event" : "Įvykis be pavadinimo",
     "{actor} created event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} sukūrė įvykį {event}",
     "You created event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} sukūrėte įvykį {event}",
     "{actor} deleted event {event} from calendar {calendar}" : "{actor} ištrynė įvykį {event} iš kalendoriaus {calendar}",
@@ -34,26 +35,15 @@ OC.L10N.register(
     "{actor} restored event {event} of calendar {calendar}" : "{actor} kalendoriuje {calendar} atkūrė įvykį {event}",
     "You restored event {event} of calendar {calendar}" : "Jūs kalendoriuje {calendar} atkūrėte įvykį {event}",
     "Busy" : "Užimtas laikas",
-    "{actor} created todo {todo} in list {calendar}" : "{actor} sąraše {calendar} sukūrė užduotį {todo}",
-    "You created todo {todo} in list {calendar}" : "Jūs sąraše {calendar} sukūrėte užduotį {todo}",
-    "{actor} deleted todo {todo} from list {calendar}" : "{actor} iš sąrašo {calendar} ištrynė užduotį {todo}",
-    "You deleted todo {todo} from list {calendar}" : "Jūs iš sąrašo {calendar} ištrynėte užduotį {todo}",
-    "{actor} updated todo {todo} in list {calendar}" : "{actor} sąraše {calendar} atnaujino užduotį {todo}",
-    "You updated todo {todo} in list {calendar}" : "Jūs sąraše {calendar} atnaujinote užduotį {todo}",
-    "{actor} solved todo {todo} in list {calendar}" : "{actor} sąraše {calendar} išsprendė užduotį {todo}",
-    "You solved todo {todo} in list {calendar}" : "Jūs sąraše {calendar} išsprendėte užduotį {todo}",
-    "{actor} reopened todo {todo} in list {calendar}" : "{actor} sąraše {calendar} vėl pradėjo užduotį {todo}",
-    "You reopened todo {todo} in list {calendar}" : "Jūs sąraše {calendar} vėl pradėjote užduotį {todo}",
     "Calendar, contacts and tasks" : "Kalendorius, adresatai ir užduotys",
     "A <strong>calendar</strong> was modified" : "<strong>Kalendorius</strong> buvo modifikuotas",
     "A calendar <strong>event</strong> was modified" : "Kalendoriaus <strong>įvykis</strong> buvo modifikuotas",
-    "A calendar <strong>todo</strong> was modified" : "Kalendoriaus <strong>užduotis</strong> buvo modifikuota",
     "Contact birthdays" : "Adresatų gimtadieniai",
+    "Untitled calendar" : "Kalendorius be pavadinimo",
     "Calendar:" : "Kalendorius:",
     "Date:" : "Data:",
     "Where:" : "Kur:",
     "Description:" : "Aprašas:",
-    "Untitled event" : "Įvykis be pavadinimo",
     "_%n year_::_%n years_" : ["%n metai","%n metai","%n metų","%n metai"],
     "_%n month_::_%n months_" : ["%n mėnesis","%n mėnesiai","%n mėnesių","%n mėnesis"],
     "_%n day_::_%n days_" : ["%n diena","%n dienos","%n dienų","%n diena"],
@@ -66,16 +56,13 @@ OC.L10N.register(
     "Description: %s" : "Aprašas: %s",
     "Where: %s" : "Kur: %s",
     "%1$s via %2$s" : "%1$s per %2$s",
-    "Invitation canceled" : "Pakvietimo atsisakyta",
-    "Invitation updated" : "Pakvietimas atnaujintas",
     "Invitation: %1$s" : "Pakvietimas: %1$s",
-    "Invitation" : "Pakvietimas",
+    "Organizer:" : "Organizatorius:",
+    "Attendees:" : "Kviestiniai:",
     "Title:" : "Pavadinimas:",
     "Time:" : "Laikas:",
     "Location:" : "Vieta:",
     "Link:" : "Nuoroda:",
-    "Organizer:" : "Organizatorius:",
-    "Attendees:" : "Kviestiniai:",
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
     "More options …" : "Daugiau parinkčių…",
@@ -92,10 +79,14 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Konfigūruoja CalDAV paskyrą",
     "Configures a CardDAV account" : "Konfigūruoja CardDAV paskyrą",
     "Events" : "Įvykiai",
-    "Tasks" : "Užduotys",
     "Untitled task" : "Užduotis be pavadinimo",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
+    "Contacts and groups" : "Adresatai ir grupės",
     "WebDAV" : "WebDAV",
     "Save" : "Įrašyti",
+    "Time zone:" : "Laiko juosta:",
+    "to" : "iki",
+    "No working hours set" : "Nenustatyta jokių darbo valandų",
     "Monday" : "Pirmadienis",
     "Tuesday" : "Antradienis",
     "Wednesday" : "Trečiadienis",
@@ -103,6 +94,7 @@ OC.L10N.register(
     "Friday" : "Penktadienis",
     "Saturday" : "Šeštadienis",
     "Sunday" : "Sekmadienis",
+    "Availability" : "Pasiekiamumas",
     "Calendar server" : "Kalendoriaus serveris",
     "Send invitations to attendees" : "Siųsti pakvietimus kviestiniams",
     "Automatically generate a birthday calendar" : "Automatiškai sukurti gimtadienių kalendorių",
@@ -114,8 +106,6 @@ OC.L10N.register(
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Įsitikinkite, kad tinkamai nusistatėte {emailopen}el. pašto serverį{linkclose}.",
     "Please contact the organizer directly." : "Prašome susisiekti su organizatoriumi tiesiogiai.",
     "Are you accepting the invitation?" : "Ar priimate pakvietimą?",
-    "Tentative" : "Preliminarus",
-    "Number of guests" : "Svečių skaičius",
-    "Calendar and tasks" : "Kalendorius ir užduotys"
+    "Tentative" : "Preliminarus"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
