@@ -10,7 +10,6 @@ OC.L10N.register(
     "Show grid view" : "Rasteransicht anzeigen",
     "Home" : "Home",
     "Close" : "Schließen",
-    "Favorites" : "Favoriten",
     "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
     "This will stop your current uploads." : "Hiermit werden die aktuellen Uploads angehalten.",
     "Upload cancelled." : "Hochladen abgebrochen.",
@@ -23,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Es ist ein unbekannter Fehler aufgetreten",
     "File could not be uploaded" : "Datei konnte nicht hochgeladen werden.",
     "Uploading …" : "Lade hoch …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Lade hoch … ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Hochladen von Daten dieser Art wird nicht unterstützt.",
     "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
@@ -33,12 +34,12 @@ OC.L10N.register(
     "Move" : "Verschieben",
     "Copy" : "Kopieren",
     "Choose target folder" : "Zielordner wählen",
+    "Set reminder" : "Erinnerung erstellen",
     "Edit locally" : "Lokal bearbeiten",
     "Open" : "Öffnen",
     "Delete file" : "Datei löschen",
     "Delete folder" : "Ordner löschen",
     "Disconnect storage" : "Speicher trennen",
-    "Leave this share" : "Diese Freigabe verlassen",
     "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
     "Files" : "Dateien",
     "Details" : "Details",
@@ -69,7 +70,7 @@ OC.L10N.register(
     "Could not fetch file details \"{file}\"" : "Details zu \"{file}\" konnten nicht ermittelt werden",
     "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Gebe mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen",
+    "Enter more than two characters to search in other folders" : "Gib mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen.",
     "Name" : "Name",
     "Size" : "Größe",
     "Modified" : "Geändert",
@@ -79,6 +80,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
     "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
     "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
+    "New" : "Neu",
     "New file/folder menu" : "Menü für neue Datei/Ordner",
     "Select file range" : "Dateibereich auswählen",
     "{used}%" : "{used}%",
@@ -98,14 +100,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
     "View in folder" : "In Ordner anzeigen",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
     "Path" : "Pfad",
     "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
     "Favorited" : "Favorisiert",
     "Favorite" : "Favorit",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
-    "You can only favorite a single file or folder at a time" : "Du kannst gleichzeitig nur eine Datei oder einen Ordner als Favorit markieren",
     "New folder" : "Neuer Ordner",
+    "Create new folder" : "Neuen Ordner erstellen",
     "Upload file" : "Datei hochladen",
     "Recent" : "Neueste",
     "Not favorited" : "Nicht favorisiert",
@@ -116,6 +116,7 @@ OC.L10N.register(
     "Removed from favorites" : "Aus den Favoriten entfernt",
     "You added {file} to your favorites" : "Du hast {file} zu deinen Favoriten hinzugefügt",
     "You removed {file} from your favorites" : "Du hast {file} aus deinen Favoriten entfernt",
+    "Favorites" : "Favoriten",
     "File changes" : "Dateiänderungen",
     "Created by {user}" : "Erstellt durch {user}",
     "Changed by {user}" : "Geändert durch {user}",
@@ -123,7 +124,6 @@ OC.L10N.register(
     "Restored by {user}" : "Wiederhergestellt durch {user}",
     "Renamed by {user}" : "Umbenannt durch {user}",
     "Moved by {user}" : "Verschoben durch {user}",
-    "\"remote user\"" : "„Externer Benutzer“",
     "You created {file}" : "Du hast {file} erstellt",
     "You created an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} erstellt",
     "{user} created {file}" : "{user} hat {file} erstellt",
@@ -152,7 +152,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde deinen <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
     "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Eine favorisierte Datei oder ein Ordner wurde <strong>geändert</strong>",
-    "All files" : "Alle Dateien",
     "Upload (max. %s)" : "Hochladen (max. %s)",
     "Accept" : "Akzeptieren",
     "Reject" : "Ablehnen",
@@ -166,15 +165,44 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
     "in %s" : "in %s",
     "File Management" : "Dateiverwaltung",
+    "Reload current directory" : "Aktuelles Verzeichnis neu laden",
+    "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}“ wechseln",
+    "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
+    "Your have used your space quota and cannot upload files anymore" : "Dein Speicherplatzkontigent ist aufgebraucht, du kannst keine weiteren Dateien hochladen.",
+    "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
+    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
+    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
+    "Rename file" : "Datei umbenennen",
+    "File name" : "Dateiname",
+    "Folder name" : "Ordnername",
+    "This node is unavailable" : "Dieser Knoten ist nicht verfügbar.",
+    "Download file {name}" : "Datei {name} herunterladen",
+    "\"{name}\" is not an allowed filetype." : "\"{name}\" ist kein zulässiger Dateityp.",
+    "{newName} already exists." : "{newName} existiert bereits.",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}“ ist innerhalb eines Dateinamens nicht zulässig.",
+    "Name cannot be empty" : "Der Name darf nicht leer sein",
+    "Another entry with the same name already exists" : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
+    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wähle einen anderen Namen.",
+    "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden.",
+    "Total rows summary" : "Zusammenfassung aller Zeilen",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
+    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
+    "List of files and folders." : "Liste der Dateien und Ordner",
+    "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste wird aus Performance-Gründen nicht vollständig angezeigt. Die Dateien werden angezeigt, wenn du durch die Liste navigierst.",
+    "File not found" : "Datei nicht gefunden",
     "Storage informations" : "Speicherinformationen",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
     "{relative}% used" : "{relative}% verwendet",
     "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
+    "Your storage is full, files can not be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
+    "Create" : "Erstellen",
     "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
     "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Change" : "Ändern",
     "New owner" : "Neuer Besitzer",
-    "Search users" : "Suche Benutzer",
     "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Transfer" : "Übertragen",
     "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
@@ -183,59 +211,107 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Anforderung für die Übertragung des Besitzes gesendet",
     "Cannot transfer ownership of a file or folder you do not own" : "Der Besitz an einer Datei oder einem Ordner, der dir nicht gehört, kann nicht übertragen werden",
     "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
+    "Choose file" : "Datei auswählen",
+    "Choose {file}" : "{file} auswählen",
+    "Loading current folder" : "Lade aktuellen Ordner",
+    "No files in here" : "Keine Dateien vorhanden",
+    "Upload some content or sync with your devices!" : "Lade Inhalte hoch oder synchronisiere sie mit deinen Geräten!",
+    "Go to the previous folder" : "Zum vorherigen Ordner wechseln",
+    "Go back" : "Zurückgehen",
+    "Share" : "Teilen",
+    "Shared by link" : "Über einen Link geteilt",
+    "Shared" : "Geteilt",
+    "Switch to list view" : "Zur Listenansicht wechseln",
+    "Switch to grid view" : "Zur Rasteransicht wechseln",
+    "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
+    "Unknown error during upload" : "unbekannte Fehler während des Hochladens",
     "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
     "Files settings" : "Dateien-Einstellungen",
     "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
-    "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise hast du nicht die Berechtigung zur Anzeige. Bitte den Absender, die Datei freizugeben.",
+    "Sort favorites first" : "Favoriten zuerst sortieren",
     "Show hidden files" : "Versteckte Dateien anzeigen",
     "Crop image previews" : "Bildvorschauen zuschneiden",
+    "Enable the grid view" : "Rasteransicht aktivieren",
     "Additional settings" : "Zusätzliche Einstellungen",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
     "Copy to clipboard" : "In die Zwischenablage kopieren",
     "Use this address to access your Files via WebDAV" : "Diese Adresse benutzen, um über WebDAV auf deine Dateien zuzugreifen",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn du 2FA aktiviert hast, musst du ein neues App-Passwort erstellen und verwenden, indem du hier klickst.",
     "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
     "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
     "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei konnte nicht geändert werden",
     "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
     "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
-    "Cancel" : "Abbrechen",
-    "Create" : "Erstellen",
     "Create a new file with the selected template" : "Eine neue Datei anhand der ausgewählten Vorlage erstellen",
     "Creating file" : "Datei erstellen",
     "Blank" : "Leer",
     "Unable to create new file from template" : "Neue Datei konnte nicht aus Vorlage erstellt werden",
-    "Set up templates folder" : "Vorlagenordner einrichten",
-    "Templates" : "Vorlagen",
+    "Delete permanently" : "Endgültig löschen",
+    "Delete files" : "Dateien löschen",
+    "Cancel" : "Abbrechen",
+    "Destination is not a folder" : "Ziel ist kein Ordner",
+    "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden.",
+    "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
+    "The file does not exist anymore" : "Die Datei existiert nicht mehr",
+    "Copy to {target}" : "Nach {target} kopieren",
+    "Move to {target}" : "Nach {target} verschieben",
+    "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
+    "Open folder {displayName}" : "Ordner {displayName} öffnen",
+    "Open in Files" : "In App \"Dateien\" öffnen",
+    "Open details" : "Details öffnen",
+    "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
+    "Filename" : "Dateiname",
     "Unable to initialize the templates directory" : "Der Vorlagenordner konnte nicht initialisiert werden",
-    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
-    "Toggle grid view" : "Rasteransicht umschalten",
-    "No files in here" : "Keine Dateien vorhanden",
-    "Upload some content or sync with your devices!" : "Inhalte hochladen oder mit deinen Geräten synchronisieren!",
+    "Create new templates folder" : "Neuen Vorlagenordner erstellen",
+    "Templates" : "Vorlagen",
+    "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
+    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden.",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
+    "List of favorites files and folders." : "Liste der favorisierten Ordner und Dateien",
+    "No favorites yet" : "Noch keine Favoriten vorhanden",
+    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
+    "All files" : "Alle Dateien",
+    "List of your files and folders." : "Liste deiner Dateien und Ordner",
+    "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner",
+    "No recently modified files" : "Keine kürzlich geänderten Dateien",
+    "Files and folders you recently modified will show up here." : "Die von dir kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
     "Select all" : "Alle auswählen",
     "Upload too large" : "Der Upload ist zu groß",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
-    "No favorites yet" : "Noch keine Favoriten vorhanden",
-    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
-    "Deleted files" : "Gelöschte Dateien",
+    "Text file" : "Textdatei",
+    "New text file.txt" : "Neue Textdatei file.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
+    "You can only favorite a single file or folder at a time" : "Du kannst gleichzeitig nur eine Datei oder einen Ordner als Favorit markieren",
+    "This file has the tag {tag}" : "Diese Datei trägt das Schlagwort {tag}.",
+    "This file has the tags {firstTags} and {lastTag}" : "Diese Datei trägt die Schlagworte {firstTags} und {lastTag}.",
+    "\"remote user\"" : "„Externer Benutzer“",
+    "Select the row for {displayName}" : "Zeile für {displayName} auswählen",
+    "Open folder {name}" : "Ordner {name} öffnen",
+    "Unselect all" : "Auswahl aufheben",
+    "ascending" : "Aufsteigend",
+    "descending" : "Absteigend",
+    "Sort list by {column} ({direction})" : "Liste sortieren nach {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Diese Liste wird aus Performance-Gründen nicht vollständig angezeigt. Die Dateien werden gerendert, wenn du durch die Liste navigierst.",
+    "Search for an account" : "Nach einem Konto suchen",
+    "Choose" : "Auswählen",
+    "No files or folders have been deleted yet" : "Es wurden noch keine Dateien oder Ordner gelöscht",
+    "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise hast du nicht die Berechtigung zur Anzeige. Bitte den Absender, die Datei freizugeben.",
+    "Set up templates folder" : "Vorlagenordner einrichten",
+    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
+    "Toggle grid view" : "Rasteransicht umschalten",
     "Shares" : "Freigaben",
     "Shared with others" : "Mit anderen geteilt",
     "Shared with you" : "Mit dir geteilt",
-    "Shared by link" : "Über einen Link geteilt",
     "Deleted shares" : "Gelöschte Freigaben",
     "Pending shares" : "Ausstehende Freigaben",
-    "Text file" : "Textdatei",
-    "New text file.txt" : "Neue Textdatei file.txt",
-    "Storage invalid" : "Speicher ungültig",
-    "Select" : "Auswählen",
-    "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
-    "New" : "Neu",
-    "Copied!" : "Kopiert!",
-    "Unlimited" : "Unbegrenzt",
-    "Cannot transfer ownership of a file or folder you don't own" : "Der Besitz einer Datei oder eines Ordners, den du nicht besitzt, kann nicht übertragen werden",
-    "%s used" : "%s verwendet",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s von %2$s verwendet",
-    "Settings" : "Einstellungen"
+    "The files is locked" : "Die Datei ist gesperrt"
 },
 "nplurals=2; plural=(n != 1);");
