@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Public link" : "Link publiczny",
     "Photos" : "Zdjęcia",
+    "On This Day" : "W tym dniu",
     "Your memories under your control" : "Twoje wspomnienia pod kontrolą",
     "All media" : "Wszystkie media",
     "Videos" : "Filmy",
@@ -14,64 +15,77 @@ OC.L10N.register(
     "On this day" : "W tym dniu",
     "Shared with you" : "Udostępnione Tobie",
     "Tags" : "Etykiety",
-    "Locations" : "Lokalizacje",
+    "Places" : "Miejsca",
+    "Map" : "Mapa",
     "Photos settings" : "Ustawienia Zdjęć",
     "Mark selection as favorite" : "Oznacz wybrane jako ulubione",
     "Add selection to favorites" : "Dodaj wybrane do ulubionych",
     "Remove selection from favorites" : "Usuń wybrane z ulubionych",
     "Name of the album" : "Nazwa albumu",
     "Location of the album" : "Lokalizacja albumu",
-    "Go back to the previous view." : "Wróć do poprzedniego widoku.",
     "Back" : "Poprzednia",
-    "Go to the add collaborators view." : "Przejdź do widoku dodawania współpracowników.",
     "Add collaborators" : "Dodaj współpracowników",
-    "Save." : "Zapisz.",
-    "Create the album." : "Utwórz album.",
     "Save" : "Zapisz",
     "Create album" : "Utwórz album",
-    "Back to the new album form." : "Powrót do nowej formy albumu.",
     "Add to Album" : "Dodaj do albumu",
     "Add selection to album {albumName}" : "Dodaj wybór do albumu {albumName}",
+    "Shared by" : "Udostępnione przez",
     "Create a new album." : "Utwórz nowy album.",
     "Create new album" : "Utwórz nowy album",
     "New album" : "Nowy album",
     "_%n item_::_%n photos and videos_" : ["%n pozycja","%n pozycje","%n pozycji","%n zdjęć i filmów"],
-    "_Share with %n user_::_Share with %n users_" : ["Udostępnij %n użytkownikowi","Udostępnij %n użytkownikom","Udostępnij %n użytkownikom","Udostępnij %n użytkownikom"],
     "Add people or groups who can edit your album" : "Dodaj osoby lub grupy, które mogą edytować Twój album",
-    "Search for collaborators" : "Szukaj współpracowników",
     "Search people or groups" : "Wyszukaj osoby lub grupy",
-    "Add {collaboratorLabel} to the collaborators list" : "Dodaj {collaboratorLabel} do listy współpracowników",
-    "No collaborators available" : "Brak dostępnych współpracowników",
+    "No recommendations. Start typing." : "Brak rekomendacji. Możesz napisać.",
+    "Group" : "Grupa",
     "Remove {collaboratorLabel} from the collaborators list" : "Usuń {collaboratorLabel} z listy współpracowników",
     "Copy the public link" : "Kopiuj link publiczny",
     "Public link copied!" : "Skopiowano link publiczny!",
     "Copy public link" : "Kopiuj link publiczny",
     "Delete the public link" : "Usuń link publiczny",
+    "Create public link share" : "Utwórz udostępnienie linku publicznego",
     "Share via public link" : "Udostępnij przez link publiczny",
     "Failed to fetch collaborators list." : "Nie udało się pobrać listy współpracowników.",
-    "Failed to fetch album." : "Nie udało się pobrać albumu.",
     "Failed to update album." : "Nie udało się zaktualizować albumu.",
     "This collection does not exist" : "Ta kolekcja nie istnieje",
     "An error occurred" : "Wystąpił błąd",
-    "_%n photos_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
+    "No picture for this day" : "Brak zdjęć z tego dnia",
+    "Picture taken on this day will show up here." : "Tutaj pojawi się zdjęcie zrobione tego dnia.",
+    "More photos from this day" : "Więcej zdjęć z tego dnia",
+    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nieprzypisane zdjęcie","%n nieprzypisane zdjęcia","%n nieprzypisanych zdjęć","%n nieprzypisanych zdjęć"],
+    "Favorite" : "Ulubiony",
     "Select image {imageName}" : "Wybierz obraz {imageName}",
-    "The file is in the favorites" : "Plik znajduje się w ulubionych",
+    "Favorite image, open the full size \"{name}\" image" : "Ulubiony obraz, otwórz pełnowymiarowy obraz „{name}”.",
     "Open the full size \"{name}\" image" : "Otwórz obraz \"{name}\" w pełnym rozmiarze",
-    "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
-    "Add to {destination}" : "Dodaj do {destination}",
-    "Open the \"{name}\" sub-directory" : "Otwórz podkatalog \"{name}\"",
+    "Open the \"{name}\" folder" : "Otwórz folder „{name}”.",
+    "Go back" : "Wstecz",
     "Back to {folder}" : "Powrót do {folder}",
     "Share this folder" : "Udostępnij ten katalog",
+    "Dates" : "Daty",
+    "Jump to specific date in list" : "Przejdź do określonej daty na liście",
+    "Jump to {date}" : "Przejdź do {date}",
+    "Add to {destination}" : "Dodaj do {destination}",
+    "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
     "_{years} year ago_::_{years} years ago_" : ["{years} rok temu","{years} lata temu","{years} lat temu","{years} lat temu"],
     "Enable squared photos view" : "Włącz zdjęcia w widoku kwadratowym",
-    "Default Photos upload and Albums location" : "Domyślna lokalizacja przesyłania zdjęć i albumów",
-    "Select the default location for your media" : "Wybierz domyślną lokalizację swoich multimediów",
-    "Invalid location selected" : "Wybrano nieprawidłową lokalizację",
+    "Delete source directory" : "Usuń katalog źródłowy",
+    "All folders" : "Wszystkie foldery",
+    "Add a Photos source for the timelines" : "Dodaj źródło zdjęć do osi czasu",
+    "Add folder" : "Dodaj folder",
+    "Select a source folder for your media" : "Wybierz folder źródłowy dla multimediów",
+    "Home" : "Strona główna",
+    "Choose default Photos upload and Albums location" : "Wybierz domyślną lokalizację wysyłania zdjęć i albumów",
+    "Choose a different folder" : "Wybierz inny folder",
+    "Select the default upload location for your media" : "Wybierz domyślną lokalizację przesyłania multimediów",
     "View" : "Podgląd",
-    "Photos directory" : "Katalog zdjęć",
+    "Media folders" : "Foldery multimedialne",
+    "Choose the folders from where photos and videos are shown." : "Wybierz foldery, z których będą wyświetlane zdjęcia i filmy.",
+    "Upload folder" : "Prześlij folder",
+    "Choose the folder where photos and albums are uploaded to." : "Wybierz folder, do którego przesyłane są zdjęcia i albumy.",
     "_%n photo_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
+    "Unselect all" : "Odznacz wszystko",
     "Manage collaborators for this album" : "Zarządzaj współpracownikami tego albumu",
-    "Open actions menu" : "Otwórz menu akcji",
+    "Open actions menu" : "Otwórz menu działań",
     "Edit album details" : "Edytuj szczegóły albumu",
     "Download all files in album" : "Pobierz wszystkie pliki z albumu",
     "Delete album" : "Usuń album",
@@ -79,7 +93,7 @@ OC.L10N.register(
     "Remove selection from album" : "Usuń wybrane z albumu",
     "This album does not have any photos or videos yet!" : "W tym albumie nie ma jeszcze żadnych zdjęć ani filmów!",
     "Add photos to this album" : "Dodaj zdjęcia do tego albumu",
-    "Add photos to the album" : "Dodaj zdjęcia do albumu",
+    "Add photos to {albumName}" : "Dodaj zdjęcia do albumu {albumName}",
     "Manage collaborators" : "Zarządzaj współpracownikami",
     "Save collaborators for this album." : "Zapisywanie współpracowników dla tego albumu.",
     "Cover photo for album {albumName}" : "Zdjęcie na okładkę albumu {albumName}",
@@ -88,44 +102,78 @@ OC.L10N.register(
     "Rename person" : "Zmień nazwę osoby",
     "Merge with different person" : "Połącz z inną osobą",
     "Download selected photos" : "Pobierz wybrane zdjęcia",
-    "Favorite" : "Ulubiony",
     "Remove from favorites" : "Usuń z ulubionych",
     "Remove person" : "Usuń osobę",
     "Name of this person" : "Nazwa tej osoby",
+    "Save." : "Zapisz.",
     "Merge person" : "Połącz osobę",
+    "Move to different person" : "Przenieś do innej osoby",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["Przenieś zdjęcie do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby"],
     "_Remove photo from person_::_Remove photos from person_" : ["Usuń zdjęcie od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby"],
     "This might take some time depending on the size of your photo library." : "Może to zająć trochę czasu, w zależności od rozmiaru biblioteki zdjęć.",
     "Recognized people will show up here" : "Rozpoznane osoby pojawią się tutaj",
     "This folder does not exist" : "Ten katalog nie istnieje",
-    "Loading folders …" : "Ładowanie katalogów …",
+    "Loading folders …" : "Wczytywanie folderów …",
     "No photos in here" : "Brak zdjęć",
-    "Failed to fetch albums list." : "Nie udało się pobrać listy albumów.",
-    "Shared albums" : "Udostępnione albumy",
+    "Taken on {date} at {time}" : "Zrobiono {date} o {time}",
+    "This place does not have any photos or videos yet!" : "To miejsce nie ma jeszcze żadnych zdjęć ani filmów!",
+    "Add photos to this place" : "Dodaj zdjęcia do tego miejsca",
+    "Cover photo for place {placeName}" : "Zdjęcie na okładkę {placeName}",
+    "There is no place yet!" : "Nie ma jeszcze miejsca!",
     "Cover photo for shared album {albumName}." : "Zdjęcie na okładkę albumu udostępnionego {albumName}.",
     "Back to tags overview" : "Powrót do przeglądania etykiet",
     "No photos with this tag yet" : "Nie ma jeszcze zdjęć z tą etykietą",
     "No tags yet" : "Brak etykiet",
     "Photos with tags will show up here" : "Zdjęcia z etykietami pojawią się tutaj",
     "Popular tags" : "Popularne etykiety",
+    "One of the source folders does not exists" : "Jeden z folderów źródłowych nie istnieje",
     "Add" : "Dodaj",
-    "Create a new album" : "Utwórz nowy album",
-    "Add selection to an album" : "Dodaj wybrane do albumu",
     "Add to album" : "Dodaj do albumu",
     "Delete selection" : "Usuń wybrane",
+    "No photos or videos in here" : "Nie ma tu zdjęć ani filmów",
+    "Unassigned faces" : "Nieprzypisane twarze",
+    "_%n photos_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
+    "Failed to fetch collection." : "Nie udało się pobrać kolekcji.",
+    "Failed to fetch collections list." : "Nie udało się pobrać listę kolekcji.",
     "Failed to fetch faces list." : "Nie udało się pobrać listy twarzy.",
     "All your media" : "Wszystkie Twoje media",
+    "Album {title}" : "Album {title}",
+    "Shared Albums" : "Albumy udostępnione",
+    "Shared album {title}" : "Udostępniony album {title}",
+    "Public album {title}" : "Publiczny album {title}",
     "Tagged photos" : "Oznaczone zdjęcia",
-    "Failed to create {albumName}." : "Nie udało się utworzyć {albumName}.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Nie udało się zmienić nazwy {currentAlbumName} na {newAlbumName}.",
+    "Tagged photo {title}" : "Zdjęcie oznaczone etykietą {title}",
+    "{title}'s face" : "Twarz {title}",
+    "{startDate} to {endDate}" : "{startDate} do {endDate}",
+    "Details" : "Szczegóły",
     "Failed to rename {oldName} to {faceName}." : "Nie udało się zmienić nazwy {oldName} na {faceName}.",
     "Failed to delete {faceName}." : "Nie udało się usunąć {faceName}.",
     "Failed to delete {fileId}." : "Nie udało się usunąć {fileId}.",
     "Failed to delete {fileName}." : "Nie udało się usunąć {fileName}.",
     "Failed to set favorite state for {fileId}." : "Nie udało się ustawić statusu ulubionego dla {fileId}.",
     "Failed to set favorite state for {fileName}." : "Nie udało się ustawić statusu ulubionego dla {fileName}.",
-    "Your photos" : "Zdjęcia",
-    "Your videos" : "Twoje filmy",
-    "Your folders" : "Twoje katalogi",
-    "Settings" : "Ustawienia"
+    "Could not load photos folder" : "Nie można wczytać folderu ze zdjęciami",
+    "Go back to the previous view." : "Wróć do poprzedniego widoku.",
+    "Go to the add collaborators view." : "Przejdź do widoku dodawania współpracowników.",
+    "Create the album." : "Utwórz album.",
+    "Back to the new album form." : "Powrót do nowej formy albumu.",
+    "_Share with %n user_::_Share with %n users_" : ["Udostępnij %n użytkownikowi","Udostępnij %n użytkownikom","Udostępnij %n użytkownikom","Udostępnij %n użytkownikom"],
+    "Search for collaborators" : "Szukaj współpracowników",
+    "Add {collaboratorLabel} to the collaborators list" : "Dodaj {collaboratorLabel} do listy współpracowników",
+    "No collaborators available" : "Brak dostępnych współpracowników",
+    "Failed to fetch album." : "Nie udało się pobrać albumu.",
+    "The file is in the favorites" : "Plik znajduje się w ulubionych",
+    "Open the \"{name}\" sub-directory" : "Otwórz podkatalog \"{name}\"",
+    "Default Photos upload and Albums location" : "Domyślna lokalizacja wysyłania zdjęć i albumów",
+    "Select the default location for your media" : "Wybierz domyślną lokalizację swoich multimediów",
+    "Invalid location selected" : "Wybrano nieprawidłową lokalizację",
+    "Photos directory" : "Katalog zdjęć",
+    "Add photos to the album" : "Dodaj zdjęcia do albumu",
+    "Failed to fetch albums list." : "Nie udało się pobrać listy albumów.",
+    "Shared albums" : "Udostępnione albumy",
+    "Create a new album" : "Utwórz nowy album",
+    "Add selection to an album" : "Dodaj wybrane do albumu",
+    "Failed to create {albumName}." : "Nie udało się utworzyć {albumName}.",
+    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Nie udało się zmienić nazwy {currentAlbumName} na {newAlbumName}."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
