@@ -2,21 +2,6 @@ OC.L10N.register(
     "serverinfo",
     {
     "CPU info not available" : "CPU information er ikke tilgængeli",
-    "Load average" : "Gennemsnitlig belastning",
-    "Last minute" : "Senest minut",
-    "Memory info not available" : "Hukommelsesinformation er ikke tilgængelig. ",
-    "Total" : "Total",
-    "Current usage" : "Nuværende forbrug",
-    "Users" : "Brugere",
-    "Groups" : "Grupper",
-    "Links" : "Links",
-    "Mails" : "Mails",
-    "Federated sent" : "Fødereret sendt",
-    "Federated received" : "Fødereret modtaget",
-    "Talk conversations" : "Snak samtaler",
-    "24 hours" : "24 timer",
-    "1 hour" : "1 time",
-    "Copy" : "Kopier",
     "Copied!" : "Kopieret!",
     "Not supported!" : "Ikke understøttet!",
     "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
@@ -25,23 +10,26 @@ OC.L10N.register(
     "Monitoring" : "Monitorering",
     "Monitoring app with useful server information" : "Monitoreringsapp med serverinformation",
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Viser serverinformation som CPU belastning, RAM forbrug, lagerforbrug, antal brugere osv.",
-    "Size" : "Størrelse",
+    "Temperature" : "Temperatur",
+    "Load" : "Belastning",
+    "Memory" : "Hukommelse",
+    "Disk" : "Disk",
+    "Size:" : "Størrelse:",
     "Files:" : "Filer:",
     "Storages:" : "Lagre:",
     "Free Space:" : "Ledig plads:",
-    "Hostname" : "Værtsnavn",
-    "Status" : "Status",
+    "Network" : "Netværk",
     "Active users" : "Aktive brugere",
+    "Total users:" : "Antal brugere:",
     "Shares" : "Delinger",
+    "Users:" : "Brugere:",
     "PHP" : "PHP",
     "Version:" : "Version:",
-    "Memory Limit:" : "Hukommelses begrænsning:",
-    "Max Execution Time:" : "Max Kørsels Tid:",
     "Upload max size:" : "Max upload størrelse:",
     "Database" : "Database",
     "Type:" : "Type:",
-    "Size:" : "Størrelse:",
     "External monitoring tool" : "Eksternt monitoreringsværktøj",
-    "You can connect an external monitoring tool by using this end point:" : "Du kan forbinde et eksternt monitoreringsprogram ved at bruge dette endepunkt:"
+    "Copy" : "Kopier",
+    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Send derefter tokenet med \"NC-Token\"-headeren, når du forespørger på ovenstående URL."
 },
 "nplurals=2; plural=(n != 1);");
