@@ -23,20 +23,20 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "თქვენ ორ-ფაქტორიანი აუტენტიფიკაციით წარმატებით გაიარეთ ავტორიზაცია (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "ავტორიზაცია ორ-ფაქტორიანი აუტენტიფიკაციით ვერ მოხერხდა (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>თქვენი პაროლი</strong> ან <strong>ელ-ფოსტის მისამართი</strong> შეიცვალა",
+    "Settings" : "პარამეტრები",
     "Wrong password" : "არასწორი პაროლი",
     "Saved" : "დამახსოვრდა",
-    "No user supplied" : "მომხმარებელი არ იქნა მოწოდებული",
     "Authentication error" : "აუტენტიფიკაციის შეცდომა",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
     "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
-    "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
+    "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
+    "User documentation" : "მომხმარებლის დოკუმენტაცია",
     "Invalid SMTP password." : "არასწორი SMTP პაროლი.",
     "Email setting test" : "ელ-ფოსტის დაყენების შემოწმება",
     "Well done, %s!" : "ყველაფერი კარგადაა, %s!",
     "If you received this email, the email configuration seems to be correct." : "იმ შემთხვევაში თუ მიიღეთ ეს ელ-წერილი, ელ-ფოსტის კონფიგურაცია კარგად უნდა იყოს.",
     "Email could not be sent. Check your mail server log" : "ელ-წერილი ვერ იგზავნება. გთხოვთ შეამოწმოთ მეილ-სერვერის ლოგი",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ელ-წერილის გაგზავნისას წარმოიშვა შეცდომა. გთხოვთ გადახედოთ თქვენს პარამეტრებს. (შეცდომა: %s)",
-    "Invalid user" : "არასწორი მომხმარებელი",
+    "Invalid account" : "არასწორი ანგარიში",
     "Invalid mail address" : "არასწორი საფოსტო მისამართი",
     "Settings saved" : "პარამეტრები შენახულია",
     "Unable to change full name" : "სრული სახელის ცვლილება ვერ ხერხდება",
@@ -58,76 +58,86 @@ OC.L10N.register(
     "Welcome aboard" : "კეთილი იყოს თქვენი ბორტზე მობრძანება",
     "Welcome aboard %s" : "%s, კეთილი იყოს თქვენი ბორტზე მობრძანება",
     "Welcome to your %s account, you can add, protect, and share your data." : "კეთილი იყოს თქვენი %s ანგარიშში მობრძანება, შეგიძლიათ დაამატოთ, დაიცვათ და გააზიაროთ თქვენი მონაცემები.",
-    "Your username is: %s" : "თქვენი მომხმარებლის სახელია: %s",
     "Set your password" : "დააყენეთ თქვენი პაროლი",
     "Go to %s" : "გადადით %s-ზე",
     "Install Client" : "დააყენეთ კლიენტი",
-    "Logged in user must be a subadmin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ქვე-ადმინისტრატორი",
     "Apps" : "აპლიკაციები",
-    "Settings" : "პარამეტრები",
     "Personal" : "პირადი",
     "Administration" : "ადმინისტრაცია",
+    "Users" : "მომხმარებლები",
     "Additional settings" : "დამატებითი პარამეტრები",
     "Overview" : "ზოგადი მიმოხილვა",
     "Basic settings" : "ძირითადი პარამეტრები",
     "Sharing" : "გაზიარება",
+    "Calendar" : "კალენდარი",
     "Personal info" : "პირადი ინფორმაცია",
     "Mobile & desktop" : "მობილური და დესკტოპი",
     "Email server" : "საფოსტო სერვერი",
     "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
     "Background jobs" : "ფონური საქმეები",
-    "Create" : "შექმნა",
-    "Change" : "შეცვლა",
-    "Delete" : "წაშლა",
     "Unlimited" : "ულიმიტო",
     "Verifying" : "მოწმდება",
+    "Disabled" : "არაა მოქმედი",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-ს ფუნქცია \"set_time_limit\" არაა ხელმისაწვდომი. ამან შეიძლება ქმედებისას გამოიწვიოს სკრიპტების შეჩერება, ინსტალაციის შეწყვეტა. რეკომენდირებულია ამ ფუნქციის ჩართვა.",
+    "Supported" : "მხარდაჭერილია",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "თქვენს PHP-ს არ აქვს FreeType-ის მხარდაჭერა, რაც გამოწვევს დარღვეულ პროფილის სურათებს და პარამეტრების ინტერფეისს.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "როგორც ჩანს PHP სისტემის გარემოს ცვლადების მიღებისთვის არაა სწორად მოწყობილი. ეს ტესტი getenv(\"PATH\")-ით აბრუნებს მხოლოდ ცარიელ პასუხს.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "თქვენი მონაცემთა ბაზა არ მოქმედებს \"READ COMMITTED\" ტრანზაქციის იზოლაციის დონით. ამან შეიძლება გამოიწვიოს პრობლემა, როდესაც მრავალი ქმედება შესრულდება პარალელურად.",
     "None" : "არც ერთი",
+    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
+    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
+    "Allow sharing with groups" : "ჯგუფებთან გაზიარების მხარდაჭერა",
+    "Restrict users to only share with users in their groups" : "შეზღუდეთ მომხმარებლები გააზიარონ მომხმარებლებთან, რომლებიც მიეკუთვნებიან მათ ჯგუფებს",
+    "Allow public uploads" : "საქვეყნო ატვირთების დაშვება",
+    "Always ask for a password" : "ყოველთვის მოხდეს პაროლის მოთხოვნა",
+    "Enforce password protection" : "პროლით დაცვის იძულება",
+    "Enforce expiration date" : "ვადის ამოწურვის თარიღის იძულება",
+    "This text will be shown on the public link upload page when the file list is hidden." : "ეს ტექსტი გამოჩნდება ღია ბმულის ატვირთვის გვერდზე, როდესაც ფაილების სია დამალულია.",
+    "Default share permissions" : "საწყისი გაზიარების პარამეტრები",
     "Limit to groups" : "ლიმიტი ჯგუფებზე",
     "Save changes" : "ცვილებების შენახვა",
+    "Remove" : "წაშლა",
+    "Disable" : "გამორთვა",
+    "Featured" : "გამორჩეულები",
+    "Icon" : "პიქტოგრამა",
+    "Name" : "სახელი",
+    "Version" : "ვერსია",
+    "Level" : "დონე",
+    "Actions" : "მოქმედებები",
+    "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
+    "Description" : "აღწერილობა",
+    "Details" : "დეტალები",
     "All" : "ყველა",
     "No results" : "შედეგები არაა",
     "Update to {version}" : "განაახლეთ ვერსიაზე {version}",
-    "Remove" : "წაშლა",
-    "Disable" : "გამორთვა",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მინიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მაქსიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "ეს აპლიკაცია ვერ დაყენდა რადგან შემდეგი დამოკიდებულებები არაა დაკმაყოფილებული:",
+    "Categories" : "კატეგორიები",
+    "Resources" : "რესურსები",
+    "Documentation" : "დოკუმენტაცია",
+    "Report a bug" : "განაცხადეთ შეცდომის შესახებ",
+    "Request feature" : "მოითხოვეთ ფუნქცია",
+    "Ask questions or discuss" : "იკითხეთ ან განიხილეთ",
+    "Rate" : "შეაფასეთ",
     "View in store" : "იხილეთ store-ში",
     "Visit website" : "საიტზე სტუმრობა",
-    "Report a bug" : "განაცხადეთ შეცდომის შესახებ",
-    "User documentation" : "მომხმარებლის დოკუმენტაცია",
     "Admin documentation" : "ადმინისტრატორის დოკუმენტაცია",
     "Developer documentation" : "დეველოპერის დოკუმენტაცია",
-    "Supported" : "მხარდაჭერილია",
-    "Featured" : "გამორჩეულები",
-    "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
-    "Enable all" : "ყველას ამოქმედება",
+    "Changelog" : "ცვლილებების ლოგი",
     "Allow filesystem access" : "ფაილ-სისტემაზე წვდომის მინიჭება",
     "Rename" : "სახელის შეცვლა",
     "Revoke" : "წვდომის გაუქმება",
-    "Internet Explorer" : "Internet Explorer-ი",
-    "Edge" : "Edge-ი",
-    "Firefox" : "Firefox-ი",
-    "Google Chrome" : "Google Chrome-ი",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome Android-ისთვის",
-    "Sync client - {os}" : "სინქ. კლიენტი - {os}",
     "This session" : "ეს სესია",
     "Device" : "მოწყობილობა",
     "Last activity" : "ბოლო აქტივობა",
     "Web, desktop and mobile clients currently logged in to your account." : "ვებ, დესკტოპ და მობილური კლიენტები ამჟამად ავტორიზირებული თქვენს ანგარიშზე.",
-    "Error while creating device token" : "მოწყობილობის ტოკენის ჩატვირთვისას წარმოიქმნა შეცდომა",
-    "Error while deleting the token" : "ტოკენის წაშლისას წარმოიქმნა შეცდომა",
     "App name" : "აპლიკაციის სახელი",
     "Create new app password" : "ახალი აპლიკაციის პაროლის შექმნა",
-    "Use the credentials below to configure your app or device." : "ქვემოთ მოცემული უფლებამოსილებანის გამოყენება აპლიკაციისა თუ მოწყობილობისთვის.",
-    "For security reasons this password will only be shown once." : "უსაფრთხოების მიზნით ეს პაროლი გამოჩნდება მხოლოდ ერთხელ.",
-    "Username" : "მომხმარებლის სახელი",
+    "Error while creating device token" : "მოწყობილობის ტოკენის ჩატვირთვისას წარმოიქმნა შეცდომა",
+    "Login" : "ლოგინი",
     "Password" : "პაროლი",
-    "Done" : "დასრულებულია",
-    "Copied!" : "კოპირებულია",
-    "Copy" : "კოპირება",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
     "Enable" : "ჩართვა",
     "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "სერვერული-მხარის შიფრაცია იძლევა სერვერზე ატვირთული ფაილების შიფრაციის საშუალებას. ეს ფუნქცია ლიმიტს აწესებს მოქმედებაზე, ასე რომ გააქტიურედ მხოლოდ აუცილებლობისას.",
@@ -139,43 +149,42 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "ეს ბოლო გაფრთხილებაა: ნამდვილად გსურთ შიფრაციის ამოქმედება?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "შიფრაციის მოდული არაა ჩატვირთული, გთხოვთ აამოქმედოთ ის აპლიკაციის მენიუდან. ",
     "Select default encryption module:" : "აირჩიეთ შიფრაციის საწყისი მოდული:",
+    "Cancel" : "უარყოფა",
+    "Confirm" : "დადასტურება",
+    "Submit" : "გაგზავნა",
     "Current password" : "მიმდინარე პაროლი",
     "New password" : "ახალი პაროლი",
     "Change password" : "პაროლის შეცვლა",
-    "png or jpg, max. 20 MB" : "png ან jpg, მაქს. 20 მბ",
     "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
-    "Cancel" : "უარყოფა",
-    "Details" : "დეტალები",
-    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
     "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
-    "Language" : "ენა",
     "Help translate" : "თარგმნის დახმარება",
     "Your phone number" : "თქვენი ტელეფონის ნომერი",
-    "Your Twitter handle" : "თქვენი Twitter-is @…",
     "Your website" : "თქვენი ვებ-საიტი",
     "Add" : "დამატება",
-    "{size} used" : "მოხმარებულია {size}",
+    "Create" : "შექმნა",
+    "Change" : "შეცვლა",
+    "Delete" : "წაშლა",
     "Display name" : "დისპლეი სახელი",
     "Email" : "ელ-ფოსტა",
-    "Group admin for" : "ადმინისტრატორის შეჯგუფება",
     "Quota" : "ქვოტა",
+    "Language" : "ენა",
+    "Avatar" : "ავატარი",
+    "Username" : "მომხმარებლის სახელი",
+    "Group admin for" : "ადმინისტრატორის შეჯგუფება",
     "User backend" : "მომხმარებელის ბექენდი",
     "Storage location" : "საცავის ადგილმდებარეობა",
     "Last login" : "ბოლო ავტორიზაცია",
+    "{size} used" : "მოხმარებულია {size}",
+    "Delete account" : "ანგარიშის გაუქმება",
+    "Done" : "დასრულებულია",
+    "Edit" : "შეცვლა",
+    "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
+    "Send email" : "ელ-წერილის გაგზავნა",
     "Default quota" : "საწყისი კვოტა",
     "Unnamed device" : "უსახელო მოწყობილობა",
-    "Your apps" : "თქვენი აპლიკაციები",
-    "Disabled apps" : "არამოქმედი აპლიკაციები",
-    "Updates" : "განახლებები",
-    "App bundles" : "აპლიკაციის შეკვრები",
-    "Changelog" : "ცვლილებების ლოგი",
-    "Add group" : "ჯგუფის დამატება",
-    "Active users" : "აქტიური მომხმარებლები",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
     "Admins" : "ადმინისტრატორები",
-    "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
-    "Show user backend" : "მომხმარებლის ბექენდის ჩვენება",
-    "Send email to new user" : "გაუგზავნეთ ელ-წერილი ახალ მომხმარებელს",
-    "Not saved" : "არაა შენახული",
+    "Group name" : "ჯგუფის სახელი",
     "Sending…" : "იგზავნება…",
     "Email sent" : "ელ-წერილი გაიგზავნა",
     "Location" : "ადგილმდებარეობა",
@@ -183,84 +192,64 @@ OC.L10N.register(
     "About" : "შესახებ",
     "Full name" : "სრული სახელი",
     "Phone number" : "ტელეფონის ნომერი",
-    "Twitter" : "Twitter-ი",
     "Website" : "ვებ-საიტი",
+    "Your apps" : "თქვენი აპლიკაციები",
+    "Disabled apps" : "არამოქმედი აპლიკაციები",
+    "Updates" : "განახლებები",
+    "App bundles" : "აპლიკაციის შეკვრები",
     "Hide" : "დამალვა",
     "Never" : "არასდროს",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
-    "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
-    "Documentation" : "დოკუმენტაცია",
     "Forum" : "ფორუმი",
-    "Login" : "ლოგინი",
-    "Plain" : "ჩვეულებრივი",
-    "NT LAN Manager" : "NT LAN მენეჯერი",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "SSL" : "SSL",
     "Open documentation" : "ღია დოკუმენტაცია",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "ამ სერვერის მოწყობა ელ-წერილების გასაგზვნად მნიშვნელოვანია, მაგ. პაროლის აღსადგენად და შეტყობინებების მისაღებად.",
     "Send mode" : "გაგზავნის რეჟიმი",
     "Encryption" : "შიფრაცია",
     "From address" : "მისამართიდან",
-    "Authentication method" : "აუტენტიფიკაციის მეთოდი",
-    "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
     "Server address" : "სერვერის მისამართი",
     "Port" : "პორტი",
+    "Authentication" : "აუტენტიფიკაცია",
+    "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
     "Credentials" : "უფლებამოსილებანი",
-    "SMTP Username" : "SMTP მოხმარებლის სახელი",
     "SMTP Password" : "SMTP მომხმარებლის პაროლი",
     "Save" : "შენახვა",
-    "Send email" : "ელ-წერილის გაგზავნა",
     "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
-    "Version" : "ვერსია",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
-    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
-    "Enforce expiration date" : "ვადის ამოწურვის თარიღის იძულება",
-    "Allow public uploads" : "საქვეყნო ატვირთების დაშვება",
-    "Always ask for a password" : "ყოველთვის მოხდეს პაროლის მოთხოვნა",
-    "Enforce password protection" : "პროლით დაცვის იძულება",
-    "Set default expiration date" : "დააყენეთ საწყისი ვადის ამოწურვის თარიღი",
-    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
-    "Allow sharing with groups" : "ჯგუფებთან გაზიარების მხარდაჭერა",
-    "Restrict users to only share with users in their groups" : "შეზღუდეთ მომხმარებლები გააზიარონ მომხმარებლებთან, რომლებიც მიეკუთვნებიან მათ ჯგუფებს",
-    "Exclude groups from sharing" : "აკრძალეთ ჯგუფების გაზიარება",
-    "These groups will still be able to receive shares, but not to initiate them." : "ეს ჯგუფები ისევ მიიღებენ გაზიარებებს, მაგრამ ვერ წამოიწყებენ მათ.",
-    "This text will be shown on the public link upload page when the file list is hidden." : "ეს ტექსტი გამოჩნდება ღია ბმულის ატვირთვის გვერდზე, როდესაც ფაილების სია დამალულია.",
-    "Default share permissions" : "საწყისი გაზიარების პარამეტრები",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "განავითარა {communityopen}Nextcloud საზოგადოებამ{linkclose}, {githubopen}კოდი{linkclose} is ლიცენზირებულია {licenseopen}AGPL ლიცენზიით{linkclose}.",
     "Like our Facebook page" : "მოიწონეთ ჩვენი Facebook გვერდი",
     "Follow us on Twitter" : "გამოგვყევით Twitter-ზე",
     "Check out our blog" : "იხილეთ ჩვენი ბლოგი",
     "Subscribe to our newsletter" : "გამოიწერეთ ჩვენი სიახლეები",
-    "Migration in progress. Please wait until the migration is finished" : "მიმდინარეობს მიგრაცია. გთხოვთ დაელოდოთ მიგრაციის დასრულებას",
-    "Migration started …" : "მიგრაცია დაიწყო …",
-    "Select a profile picture" : "აირჩიეთ პროფილის სურათი",
-    "Couldn't remove app." : "აპლიკაციის წაშლა ვერ მოხერხდა.",
-    "Couldn't update app." : "აპლიკაციის განახლება ვერ მოხერხდა.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "ბექენდს არ აქვს პაროლის ცვლილების მხარდაჭერა, თუმცა მომხმარებლის შიფრაციის გასაღები განახლდა.",
-    "You need to set your user email before being able to send test emails." : "შემოწმების წერილების გაგზავნამდე, უნდა დააყენოთ თქვენი მომხმარებლის ელ-ფოსტა.",
-    "All languages" : "ყველა ენა",
-    "Everyone" : "ყველა",
-    "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
-    "Please read carefully before activating server-side encryption: " : "სანამ გააქტიურებთ სერვერული-მხარის შიფრაციას გთხოვთ ყურადღებით გაეცნოთ:",
-    "Enable encryption" : "შიფრაციის ამოქმედება",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "საჭიროა შიფრაციის გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე. გთხოვთ აამოქმედოთ \"საწყისი მიგრაციის მოდული\" და გაუშვათ 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "საჭიროა შიფრაციის ძველი გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე.",
-    "Start migration" : "მიგრაციის დაწყება",
-    "Last job execution ran %s. Something seems wrong." : "ბოლო საქმე გაიშვა %s. რაღაც არასწორია.",
-    "Last job ran %s." : "ბოლო საქმის გაშვება - %s.",
-    "Background job didn’t run yet!" : "ფონური საქმე ჯერ არ გაშვებულა!",
-    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php უნდა გაუშვას სისტემურმა მოხმარებელმა \"%s\".",
-    "days" : "დღე",
-    "Upload new" : "ახალი ატვირთვა",
-    "Select from Files" : "აირჩიეთ ფაილებიდან",
-    "Remove image" : "სურათის წაშლა",
-    "Choose as profile picture" : "აირჩიეთ პროფილის სურათად",
-    "No display name set" : "დისპლეი სახელი არაა დაყენებული",
-    "Address" : "მისამართი",
-    "Your postal address" : "თქვენი საფოსტო მისამართი",
-    "It can take up to 24 hours before the account is displayed as verified." : "თქვენი ანგარიშის ვერიფიცირებულად გამოჩენამ შეიძლება გასტანოს 24 საათი.",
-    "Link https://…" : "ბმული https://…",
-    "Twitter handle @…" : "Twitter @…",
-    "Avatar" : "ავატარი"
+    "No user supplied" : "მომხმარებელი არ იქნა მოწოდებული",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
+    "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
+    "Invalid user" : "არასწორი მომხმარებელი",
+    "Your username is: %s" : "თქვენი მომხმარებლის სახელია: %s",
+    "Logged in user must be a subadmin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ქვე-ადმინისტრატორი",
+    "Enable all" : "ყველას ამოქმედება",
+    "Internet Explorer" : "Internet Explorer-ი",
+    "Edge" : "Edge-ი",
+    "Firefox" : "Firefox-ი",
+    "Google Chrome" : "Google Chrome-ი",
+    "Safari" : "Safari",
+    "Sync client - {os}" : "სინქ. კლიენტი - {os}",
+    "Error while deleting the token" : "ტოკენის წაშლისას წარმოიქმნა შეცდომა",
+    "Use the credentials below to configure your app or device." : "ქვემოთ მოცემული უფლებამოსილებანის გამოყენება აპლიკაციისა თუ მოწყობილობისთვის.",
+    "For security reasons this password will only be shown once." : "უსაფრთხოების მიზნით ეს პაროლი გამოჩნდება მხოლოდ ერთხელ.",
+    "Copied!" : "კოპირებულია",
+    "Copy" : "კოპირება",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
+    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
+    "Your Twitter handle" : "თქვენი Twitter-is @…",
+    "Add group" : "ჯგუფის დამატება",
+    "Active users" : "აქტიური მომხმარებლები",
+    "Show user backend" : "მომხმარებლის ბექენდის ჩვენება",
+    "Send email to new user" : "გაუგზავნეთ ელ-წერილი ახალ მომხმარებელს",
+    "Not saved" : "არაა შენახული",
+    "Twitter" : "Twitter-ი",
+    "SMTP Username" : "SMTP მოხმარებლის სახელი",
+    "Set default expiration date" : "დააყენეთ საწყისი ვადის ამოწურვის თარიღი",
+    "Exclude groups from sharing" : "აკრძალეთ ჯგუფების გაზიარება",
+    "These groups will still be able to receive shares, but not to initiate them." : "ეს ჯგუფები ისევ მიიღებენ გაზიარებებს, მაგრამ ვერ წამოიწყებენ მათ."
 },
 "nplurals=2; plural=(n!=1);");
