@@ -1,8 +1,6 @@
 OC.L10N.register(
     "text",
     {
-    "New text file" : "Нова текстуална датотека",
-    "Create new text file" : "Креирај нова текстуална датотека",
     "The file was uploaded" : "Датотеката е прикачена",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која е одредена во HTML формата",
@@ -14,16 +12,18 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "Нема прикачена дадотека или големината го надмминува максимумот од %s",
     "Nextcloud Text" : "Текст",
     "text document" : "текстуален документ",
+    "New text file" : "Нова текстуална датотека",
+    "Create new text file" : "Креирај нова текстуална датотека",
     "{user} has mentioned you in the text document {node}" : "{user} те спомна во текстуална датотека {node}",
     "Readme" : "Прочитај",
     "Text" : "Текст",
     "📝 Collaborative document editing" : "📝 Колаборативно уредување на документи",
+    "Translate" : "Преведи",
+    "Delete task" : "Избриши задача",
     "Use current version" : "Користи ја моменталната верзија",
     "Use the saved version" : "Користи ја зачуваната верзија",
-    "Document idle for {timeout} minutes, click to continue editing" : "Документот е неактивен {timeout} минути, кликни за да продолжиш со уредување",
     "Reconnect" : "Повторно поврзување",
-    "The document has been changed outside of the editor. The changes cannot be applied." : "Документот не е изменет од уредникот. Промените не можат да се применат.",
-    "File could not be loaded. Please check your internet connection." : "Датотеката неможе да се вчита. Проверете ја вашата интернет врска.",
+    "Document idle for {timeout} minutes, click to continue editing" : "Документот е неактивен {timeout} минути, кликни за да продолжиш со уредување",
     "This file is opened read-only as it is currently locked by {user}." : "Оваа датотека е отворена како за читање и истата е заклучена од {user}.",
     "Close outline view" : "Затвори преглед",
     "Outline" : "Преглед",
@@ -42,8 +42,8 @@ OC.L10N.register(
     "Saving …" : "Зачувува ...",
     "Saved" : "Зачувано",
     "Last saved {lastSave}" : "Последно зачувано {lastSave}",
+    "The document has been changed outside of the editor. The changes cannot be applied." : "Документот не е изменет од уредникот. Промените не можат да се применат.",
     "Unsaved changes" : "Незачувани промени",
-    "Formatting help" : "Помош за форматирање",
     "Speed up your writing with simple shortcuts." : "Забрзајте го вашето пишување со овие едноставни кратенки.",
     "Style" : "Стил",
     "Syntax" : "Синтакса",
@@ -63,18 +63,26 @@ OC.L10N.register(
     "Ordered list" : "Подредена листа",
     "Quoted text" : "Цитиран текст",
     "Some code" : "Некој код",
+    "Insert emoji" : "Вметни емотикон",
+    "Undo" : "Назад",
+    "Redo" : "Напред",
+    "Alt" : "Alt",
+    "Save changes" : "Зачувај ги промените",
+    "Cancel" : "Откажи",
+    "URL" : "Адреса",
+    "Cannot copy, please copy the link manually" : "Неможе да се копира, копирајте го линкот рачно",
     "Upload from computer" : "Прикачи од компјутер",
     "Insert from Files" : "Вметни од датотеките",
+    "Formatting help" : "Помош за форматирање",
     "Select file or folder to link to" : "Изберете датотека или папка за линк до",
     "Editor actions" : "Акции на уредникот",
-    "Translate" : "Преведи",
     "Select language" : "Изберете јазик",
     "to" : "до",
     "Replace" : "Преклопи",
     "No emoji found" : "Не се пронајдени емотикони",
+    "Edit" : "Уреди",
     "Source code" : "Изворен код",
     "Failed to load" : "Неуспешно вчитување",
-    "Unsupported image type" : "Неподржан вид на слика",
     "Add row before" : "Додади ред пред",
     "Add row after" : "Додади ред после",
     "Delete this row" : "Избриши го овој ред",
@@ -82,9 +90,6 @@ OC.L10N.register(
     "Add column after" : "Додади колона после",
     "Delete this column" : "Избриши ја оваа колона",
     "Delete this table" : "Избриши ја оваа табела",
-    "Show rich workspaces" : "Прикажи збогатен работен простор",
-    "Undo" : "Назад",
-    "Redo" : "Напред",
     "Headings" : "Заглавија",
     "Heading 2" : "Заглавие 2",
     "Heading 3" : "Заглавие 3",
@@ -94,18 +99,11 @@ OC.L10N.register(
     "Success" : "Успешно",
     "Warning" : "Предупредување",
     "Table" : "Табела",
-    "Insert emoji" : "Вметни емотикон",
     "Command" : "Команда",
     "Control" : "Контрола",
     "Option" : "Опции",
     "Add notes, lists or links …" : "Додади белешки, листи или линкови ...",
-    "Edit" : "Уреди",
-    "Add description" : "Додади опис",
-    "Document save status" : "Статус на зачувување на документот",
-    "Update Link" : "Ажурирај линк",
-    "Add Link" : "Додади линк",
-    "Link file" : "Поврзи датотека (Линк)",
-    "Remove Link" : "Острани линк",
-    "Select file to link to" : "Изберете датотека за линк до неа"
+    "Show rich workspaces" : "Прикажи збогатен работен простор",
+    "Add description" : "Додади опис"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
