@@ -4,15 +4,16 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den opplasta fila er større enn variabelen MAX_FILE_SIZE i HTML-skjemaet",
     "No file was uploaded" : "Ingen filer vart lasta opp",
     "Missing a temporary folder" : "Manglar ei mellombels mappe",
+    "Translate" : "Translate",
     "Guest" : "Gjest",
     "Saved" : "Lagra",
     "Keyboard shortcuts" : "Tastatursnarvegar",
-    "Translate" : "Translate",
+    "URL" : "URL",
     "Select language" : "Vel språk",
     "to" : "til",
     "Replace" : "Erstatt",
+    "Edit" : "Endra",
     "Info" : "Info",
-    "Warning" : "Åtvaring",
-    "Edit" : "Endra"
+    "Warning" : "Åtvaring"
 },
 "nplurals=2; plural=(n != 1);");
