@@ -5,10 +5,9 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das config-Verzeichnis gegeben wird.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Wenn Sie jedoch möchten, dass die Datei config.php schreibgeschützt bleiben soll, dann setzen Sie die Option \"config_is_read_only\" in der Datei auf true.",
     "See %s" : "Siehe %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Die Dateien der App %1$s wurden nicht korrekt ersetzt. Stellen Sie sicher, dass es sich um eine mit dem Server kompatible Version handelt.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Die Anwendung %1$s ist nicht vorhanden oder hat eine mit diesem Server nicht kompatible Version. Bitte überprüfen Sie das Apps-Verzeichnis.",
     "Sample configuration detected" : "Beispielkonfiguration gefunden",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Es wurde festgestellt, dass die Beispielkonfiguration kopiert wurde. Dies kann Ihre Installation zerstören und wird nicht unterstützt. Bitte die Dokumentation lesen, bevor Änderungen an der config.php vorgenommen werden.",
-    "404" : "404",
     "The page could not be found on the server." : "Die Seite konnte auf dem Server nicht gefunden werden.",
     "%s email verification" : "%s E-Mail-Überprüfung",
     "Email verification" : "E-Mail-Überprüfung",
@@ -24,6 +23,7 @@ OC.L10N.register(
     "Enterprise bundle" : "Firmen-Paket",
     "Groupware bundle" : "Groupware-Paket",
     "Hub bundle" : "Hub-Paket",
+    "Public sector bundle" : "Paket für den öffentlichen Sektor",
     "Social sharing bundle" : "Paket für das Teilen in sozialen Medien",
     "PHP %s or higher is required." : "PHP %s oder höher wird benötigt.",
     "PHP with a version lower than %s is required." : "PHP wird in einer früheren Version als %s benötigt.",
@@ -37,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Folgende Plattformen werden unterstützt: %s",
     "Server version %s or higher is required." : "Server Version %s oder höher wird benötigt.",
     "Server version %s or lower is required." : "Server Version %s oder niedriger wird benötigt.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Der angemeldete Benutzer muss ein Administrator, ein Teil-Administrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen. ",
-    "Logged in user must be an admin or sub admin" : "Der angemeldete Benutzer muss ein (Sub-)Administrator sein",
-    "Logged in user must be an admin" : "Der angemeldete Benutzer muss ein Administrator sein",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrator, ein Teil-Administrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
+    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Sub-)Administrator sein",
+    "Logged in account must be an admin" : "Das angemeldete Konto muss ein Administrator sein",
     "Wiping of device %s has started" : "Löschen von Gerät %s wurde gestartet",
     "Wiping of device »%s« has started" : "Löschen von Gerät »%s« wurde gestartet",
     "»%s« started remote wipe" : "»%s« hat das Löschen aus der Ferne gestartet",
@@ -55,8 +55,10 @@ OC.L10N.register(
     "Authentication" : "Authentifizierung",
     "Unknown filetype" : "Unbekannter Dateityp",
     "Invalid image" : "Ungültiges Bild",
-    "Avatar image is not square" : "Benutzerbild ist nicht quadratisch",
+    "Avatar image is not square" : "Avatar-Bild ist nicht quadratisch",
+    "Files" : "Dateien",
     "View profile" : "Profil ansehen",
+    "Local time: %s" : "Ortszeit: %s",
     "today" : "Heute",
     "tomorrow" : "Morgen",
     "yesterday" : "Gestern",
@@ -91,8 +93,8 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Die App \"%s\" kann nicht installiert werden, da sie mit dieser Serverversion nicht kompatibel ist.",
     "__language_name__" : "Deutsch (Förmlich: Sie)",
     "This is an automatically sent email, please do not reply." : "Dies ist eine automatisch versandte E-Mail, bitte nicht antworten.",
-    "Help" : "Hilfe",
-    "Appearance and accessibility" : "Aussehen und Zugänglichkeit",
+    "Help & privacy" : "Hilfe & Datenschutz",
+    "Appearance and accessibility" : "Aussehen und Barrierefreiheit",
     "Apps" : "Apps",
     "Personal settings" : "Persönliche Einstellungen",
     "Administration settings" : "Administrationseinstellungen",
@@ -101,6 +103,8 @@ OC.L10N.register(
     "Users" : "Benutzer",
     "Email" : "E-Mail",
     "Mail %s" : "E-Mail %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Zeige %s auf dem Fediverse",
     "Phone" : "Telefon",
     "Call %s" : "%s anrufen",
     "Twitter" : "Twitter",
@@ -110,24 +114,26 @@ OC.L10N.register(
     "Address" : "Adresse",
     "Profile picture" : "Profilbild",
     "About" : "Über",
-    "Full name" : "Vollständiger Name",
+    "Display name" : "Anzeigename",
     "Headline" : "Überschrift",
     "Organisation" : "Organisation",
     "Role" : "Funktion",
-    "Unknown user" : "Unbekannter Benutzer",
+    "Unknown account" : "Unbekanntes Konto",
     "Additional settings" : "Zusätzliche Einstellungen",
-    "Enter the database username and name for %s" : "Den Datenbankbenutzernamen und den Namen eingeben für %s",
-    "Enter the database username for %s" : "Den Datenbankbenutzernamen eingeben für %s",
+    "Enter the database Login and name for %s" : "Den Datenbankanmeldenamen und den Namen für %s eingeben",
+    "Enter the database Login for %s" : "Anmeldenamen für die Datenbank für %s eingeben",
     "Enter the database name for %s" : "Den Datenbanknamen eingeben für %s",
     "You cannot use dots in the database name %s" : "Sie dürfen keine Punkte im Datenbanknamen %s verwenden",
-    "MySQL username and/or password not valid" : "MySQL-Benutzername und/oder Passwort ungültig",
+    "MySQL Login and/or password not valid" : "MySQL Anmeldename und/oder Passwort ungültig",
     "You need to enter details of an existing account." : "Sie müssen Details von einem existierenden Benutzer einfügen.",
     "Oracle connection could not be established" : "Es konnte keine Verbindung zur Oracle-Datenbank hergestellt werden",
-    "Oracle username and/or password not valid" : "Oracle-Benutzername und/oder -Passwort ungültig",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL-Benutzername und/oder -Passwort ungültig",
+    "Oracle Login and/or password not valid" : "Oracle-Anmeldename und/oder -Passwort ungültig",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL-Anmeldename und/oder Passwort ungültig",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X wird nicht unterstützt und %s wird auf dieser Plattform nicht richtig funktionieren. Die Benutzung erfolgt auf eigene Gefahr!",
     "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
-    "Set an admin username." : "Einen Administrations-Benutzernamen setzen.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte entfernen Sie die open_basedir-Einstellung in Ihrer php.ini oder wechseln Sie zu 64-Bit-PHP.",
+    "Set an admin Login." : "Anmeldename für Andministration setzen.",
     "Set an admin password." : "Ein Administrationspasswort setzen.",
     "Cannot create or write into the data directory %s" : "Das Datenverzeichnis %s kann nicht erstellt oder es kann darin nicht geschrieben werden.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Freigabe-Backend %s muss in der OCP\\Share_Backend - Schnittstelle implementiert werden",
@@ -145,12 +151,13 @@ OC.L10N.register(
     "Expiration date is in the past" : "Das Ablaufdatum liegt in der Vergangenheit.",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Das Ablaufdatum kann nicht mehr als %n Tag in der Zukunft liegen","Das Ablaufdatum kann nicht mehr als %n Tage in der Zukunft liegen"],
     "Sharing is only allowed with group members" : "Teilen ist nur mit Gruppenmitgliedern erlaubt",
-    "Sharing %s failed, because this item is already shared with user %s" : "Freigabe von %s fehlgeschlagen, da dieses Element schon mit dem Benutzer %s geteilt wird",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Freigeben von %s ist fehlgeschlagen, da dieses Element schon mit dem Konto %s geteilt wurde",
     "%1$s shared »%2$s« with you" : "%1$s hat »%2$s« mit Ihnen geteilt",
     "%1$s shared »%2$s« with you." : "%1$s hat »%2$s« mit Ihnen geteilt.",
     "Click the button below to open it." : "Klicken Sie zum Öffnen auf die untere Schaltfläche.",
     "The requested share does not exist anymore" : "Die angeforderte Freigabe existiert nicht mehr",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Das Benutzerlimit wurde erreicht und der Benutzer wurde nicht erstellt. Überprüfen Sie Ihre Benachrichtigungen, um mehr zu erfahren.",
+    "The requested share comes from a disabled user" : "Die angeforderte Freigabe stammt von einem deaktivierten Benutzer",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Der Benutzer wurde nicht erstellt, da das Benutzerlimit erreicht wurde. Überprüfen Sie Ihre Benachrichtigungen, um mehr zu erfahren.",
     "Could not find category \"%s\"" : "Die Kategorie \"%s“ konnte nicht gefunden werden",
     "Sunday" : "Sonntag",
     "Monday" : "Montag",
@@ -197,15 +204,15 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dez.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“ und „_.@-'“",
-    "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
-    "Username contains whitespace at the beginning or at the end" : "Der Benutzername enthält Leerzeichen am Anfang oder am Ende",
-    "Username must not consist of dots only" : "Der Benutzername darf nicht nur aus Punkten bestehen",
-    "Username is invalid because files already exist for this user" : "Der Benutzer ist ungültig, da bereits Dateien von diesem Benutzer existieren",
     "A valid password must be provided" : "Es muss ein gültiges Passwort eingegeben werden",
-    "The username is already being used" : "Dieser Benutzername existiert bereits",
-    "Could not create user" : "Benutzer konnte nicht erstellt werden",
-    "User disabled" : "Benutzer deaktiviert",
+    "The Login is already being used" : "Dieser Anmeldename wird bereits verwendet",
+    "Could not create account" : "Konto konnte nicht erstellt werden",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Nur die folgenden Zeichen sind in einem Anmeldenamen erlaubt: \"a-z\", \"A-Z\", \"0-9\", Leerzeichen und \"_.@-'\"",
+    "A valid Login must be provided" : "Ein gültiger Anmeldename muss angegeben werden.",
+    "Login contains whitespace at the beginning or at the end" : "Anmeldename enthält Leerzeichen am Anfang oder am Ende",
+    "Login must not consist of dots only" : "Der Anmeldename darf nicht nur aus Punkten bestehen",
+    "Login is invalid because files already exist for this user" : "Der Anmeldename ist ungültig, da bereits Dateien von diesem Benutzer existieren",
+    "Account disabled" : "Konto deaktiviert",
     "Login canceled by app" : "Anmeldung durch die App abgebrochen",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Die App „%1$s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %2$s",
     "a safe home for all your data" : "ein sicherer Ort für all Ihre Daten",
@@ -232,18 +239,14 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Eine Änderung dieser Einstellung in der php.ini kann Ihre Nextcloud wieder lauffähig machen.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bitte setzen Sie zum Beheben dieses Problems <code>mbstring.func_overload</code> in Ihrer php.ini auf <code>0</code>.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 ist mindestestens erforderlich. Im Moment ist %s installiert.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Um den Fehler zu beheben, müssen Sie die libxml2 Version aktualisieren und den Webserver neustarten.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
     "Please ask your server administrator to restart the web server." : "Bitte kontaktieren Sie Ihre Server-Administration und bitten Sie um den Neustart des Webservers.",
     "The required %s config variable is not configured in the config.php file." : "Die erforderliche %s Konfigurationsvariable ist in der config.php nicht konfiguriert.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Bitten Sie Ihre Server-Administration, die Nextcloud-Konfiguration zu überprüfen.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 benötigt.",
-    "Please upgrade your database version." : "Bitte aktualisieren Sie Ihre Datenbankversion.",
-    "Your data directory is readable by other users." : "Ihr Datenverzeichnis kann von anderen Benutzern gelesen werden.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bitte ändern Sie die Berechtigungen auf 0770, so dass das Verzeichnis nicht von anderen Benutzern angezeigt werden kann.",
+    "Your data directory is readable by other people." : "Ihr Datenverzeichnis kann von Anderen gelesen werden.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Bitte ändern Sie die Berechtigungen auf 0770, so dass das Verzeichnis nicht von Anderen angezeigt werden kann.",
     "Your data directory must be an absolute path." : "Ihr Datenverzeichnis muss einen absoluten Pfad haben.",
     "Check the value of \"datadirectory\" in your configuration." : "Überprüfen Sie den Wert von „datadirectory“ in Ihrer Konfiguration.",
     "Your data directory is invalid." : "Ihr Datenverzeichnis ist ungültig.",
@@ -259,31 +262,38 @@ OC.L10N.register(
     "Storage connection error. %s" : "Verbindungsfehler zum Speicherplatz. %s",
     "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Speicherplatz. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das config-Verzeichnis gegeben wird.",
-    "%s enter the database username and name." : "%s geben Sie den Datenbank-Benutzernamen  und den Datenbanknamen an.",
-    "%s enter the database username." : "%s geben Sie den Datenbank-Benutzernamen an.",
-    "%s enter the database name." : "%s geben Sie den Datenbanknamen an.",
-    "%s you may not use dots in the database name" : "%s Der Datenbankname darf keine Punkte enthalten",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte entfernen Sie die open_basedir-Einstellung in Ihrer php.ini oder wechseln Sie zu 64-Bit-PHP.",
-    "The user limit has been reached and the user was not created." : "Die Benutzergrenze wurde erreicht und der Benutzer wurde nicht erstellt.",
-    "Cannot read file" : "Datei kann nicht gelesen werden",
-    "Cannot write into \"config\" directory" : "Schreiben in das „config“-Verzeichnis ist nicht möglich",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Web-Server Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
-    "Cannot write into \"apps\" directory" : "Schreiben in das „apps“-Verzeichnis ist nicht möglich",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
-    "Cannot create \"data\" directory" : "Kann das \"Daten\"-Verzeichnis nicht erstellen.",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Dies kann zumeist behoben werden, indem dem Web-Server Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Berechtigungen können zumeist korrigiert werden indem dem Web-Server Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
-    "Setting locale to %s failed" : "Das Setzen der Umgebungslokale auf %s ist fehlgeschlagen",
-    "Please install one of these locales on your system and restart your webserver." : "Bitte installieren Sie eine dieser Sprachen auf Ihrem System und starten Sie den Webserver neu.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload ist nicht auf den erwarteten Wert „0“, sondern stattdessen  auf „%s“ gesetzt",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bitte setzen Sie zum Beheben dieses Problems <code>mbstring.func_overload</code> in Ihrer php.ini auf <code>0</code>.",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 benötigt",
-    "Please upgrade your database version" : "Bitte aktualisieren Sie Ihre Datenbankversion",
-    "Your data directory is readable by other users" : "Ihr Datenverzeichnis kann von anderen Benutzern gelesen werden",
-    "Your data directory must be an absolute path" : "Ihr Datenverzeichnis muss einen eindeutigen Pfad haben",
-    "Check the value of \"datadirectory\" in your configuration" : "Überprüfen Sie bitte die Angabe unter „datadirectory“ in Ihrer Konfiguration",
-    "Your data directory is invalid" : "Ihr Datenverzeichnis ist ungültig."
+    "Free prompt" : "Freie Eingabeaufforderung",
+    "Runs an arbitrary prompt through the language model." : "Führt eine beliebige Eingabeaufforderung über das Sprachmodell aus.",
+    "Generate headline" : "Kopfzeile erzeugen",
+    "Generates a possible headline for a text." : "Erzeugt eine mögliche Überschrift für einen Text.",
+    "Summarize" : "Zusammenfassen",
+    "Summarizes text by reducing its length without losing key information." : "Fasst Text zusammen, indem die Länge reduziert wird, ohne dass wichtige Informationen verloren gehen.",
+    "Extract topics" : "Themen extrahieren",
+    "Extracts topics from a text and outputs them separated by commas." : "Extrahiert Themen aus einem Text und gibt sie durch Kommas getrennt aus.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Der angemeldete Benutzer muss ein Administrator, ein Teil-Administrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen. ",
+    "Logged in user must be an admin or sub admin" : "Der angemeldete Benutzer muss ein (Sub-)Administrator sein",
+    "Logged in user must be an admin" : "Der angemeldete Benutzer muss ein Administrator sein",
+    "Help" : "Hilfe",
+    "Unknown user" : "Unbekannter Benutzer",
+    "Enter the database username and name for %s" : "Den Datenbankbenutzernamen und den Namen eingeben für %s",
+    "Enter the database username for %s" : "Den Datenbankbenutzernamen eingeben für %s",
+    "MySQL username and/or password not valid" : "MySQL-Benutzername und/oder Passwort ungültig",
+    "Oracle username and/or password not valid" : "Oracle-Benutzername und/oder -Passwort ungültig",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL-Benutzername und/oder -Passwort ungültig",
+    "Set an admin username." : "Einen Administrations-Benutzernamen setzen.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Freigabe von %s fehlgeschlagen, da dieses Element schon mit dem Benutzer %s geteilt wird",
+    "The username is already being used" : "Dieser Benutzername existiert bereits",
+    "Could not create user" : "Benutzer konnte nicht erstellt werden",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“, Leerzeichen und „_.@-'“",
+    "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
+    "Username contains whitespace at the beginning or at the end" : "Der Benutzername enthält Leerzeichen am Anfang oder am Ende",
+    "Username must not consist of dots only" : "Der Benutzername darf nicht nur aus Punkten bestehen",
+    "Username is invalid because files already exist for this user" : "Der Benutzer ist ungültig, da bereits Dateien von diesem Benutzer existieren",
+    "User disabled" : "Benutzer deaktiviert",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 benötigt.",
+    "Please upgrade your database version." : "Bitte aktualisieren Sie Ihre Datenbankversion.",
+    "Your data directory is readable by other users." : "Ihr Datenverzeichnis kann von anderen Benutzern gelesen werden.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bitte ändern Sie die Berechtigungen auf 0770, so dass das Verzeichnis nicht von anderen Benutzern angezeigt werden kann."
 },
 "nplurals=2; plural=(n != 1);");
