@@ -2,9 +2,19 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Esto generalmente se puede solucionar otorgando permisos de escritura al servidor web en el directorio de configuración.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Sin embargo, si prefieres mantener el archivo config.php como de solo lectura, establece la opción \"config_is_read_only\" en true.",
     "See %s" : "Ver %s",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "La aplicación %1$s no está presente o tiene una versión no compatible con este servidor. Por favor, revisa el directorio de aplicaciones.",
     "Sample configuration detected" : "Se ha detectado la configuración de muestra",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que la configuración de muestra ha sido copiada. Esto puede arruiniar tu instalacón y no está soportado. Por favor lee la documentación antes de hacer cambios en el archivo config.php",
+    "The page could not be found on the server." : "No se pudo encontrar la página en el servidor.",
+    "%s email verification" : "%s verificación de correo electrónico",
+    "Email verification" : "Verificación de correo electrónico",
+    "Click the following button to confirm your email." : "Haz clic en el siguiente botón para confirmar tu correo electrónico.",
+    "Click the following link to confirm your email." : "Haz clic en el siguiente enlace para confirmar tu correo electrónico.",
+    "Confirm your email" : "Confirma tu correo electrónico",
+    "Other activities" : "Otras actividades",
     "%1$s and %2$s" : "%1$s y %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
@@ -12,19 +22,39 @@ OC.L10N.register(
     "Education Edition" : "Edición Educativa",
     "Enterprise bundle" : "Paquete empresarial",
     "Groupware bundle" : "Paquete de Groupware",
+    "Hub bundle" : "Paquete Hub",
     "Social sharing bundle" : "Paquete para compartir en redes sociales",
     "PHP %s or higher is required." : "Se requiere de PHP %s o superior.",
     "PHP with a version lower than %s is required." : "PHP con una versión inferiror a la %s es requerido. ",
     "%sbit or higher PHP required." : "se requiere PHP para %sbit o superior.",
+    "The following architectures are supported: %s" : "Las siguientes arquitecturas son compatibles: %s",
+    "The following databases are supported: %s" : "Las siguientes bases de datos son compatibles: %s",
     "The command line tool %s could not be found" : "No fue posible encontar la herramienta de línea de comando %s",
     "The library %s is not available." : "La biblioteca %s no está disponible. ",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Se requiere la biblioteca %1$s con una versión superior a %2$s; la versión disponible es %3$s.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Se requiere la biblioteca %1$s con una versión inferior a %2$s; la versión disponible es %3$s.",
+    "The following platforms are supported: %s" : "Las siguientes plataformas son compatibles: %s",
     "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
     "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
-    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
+    "Wiping of device %s has started" : "El borrado del dispositivo %s ha comenzado",
+    "Wiping of device »%s« has started" : "El borrado del dispositivo »%s« ha comenzado",
+    "»%s« started remote wipe" : "»%s« ha iniciado el borrado remoto",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositivo o la aplicación »%s« ha iniciado el proceso de borrado remoto. Recibirás otro correo electrónico una vez que el proceso haya finalizado.",
+    "Wiping of device %s has finished" : "El borrado del dispositivo %s ha finalizado",
+    "Wiping of device »%s« has finished" : "El borrado del dispositivo »%s« ha finalizado",
+    "»%s« finished remote wipe" : "»%s« ha finalizado el borrado remoto",
+    "Device or application »%s« has finished the remote wipe process." : "El dispositivo o la aplicación »%s« ha finalizado el proceso de borrado remoto.",
+    "Remote wipe started" : "Borrado remoto iniciado",
+    "A remote wipe was started on device %s" : "Se ha iniciado un borrado remoto en el dispositivo %s",
+    "Remote wipe finished" : "Borrado remoto finalizado",
+    "The remote wipe on %s has finished" : "El borrado remoto en %s ha finalizado",
     "Authentication" : "Autenticación",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
+    "Files" : "Archivos",
+    "View profile" : "Ver perfil",
+    "Local time: %s" : "Hora local: %s",
     "today" : "hoy",
     "tomorrow" : "mañana",
     "yesterday" : "ayer",
@@ -44,8 +74,12 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos","Hace %n minutos"],
     "in a few seconds" : "en algunos segundos",
     "seconds ago" : "hace segundos",
+    "Empty file" : "Archivo vacío",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Por favor hablíitalo en tus configuraciones de aplicación o contacta a tu administrador.  ",
     "File already exists" : "El archivo ya existe",
+    "Invalid path" : "Ruta no válida",
+    "Failed to create file from template" : "Error al crear el archivo a partir de la plantilla",
+    "Templates" : "Plantillas",
     "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
     "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
     "File name is too long" : "El nombre del archivo es demasiado largo",
@@ -55,39 +89,61 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
     "__language_name__" : "Español (Ecuador)",
     "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, por favor no lo contestes. ",
-    "Help" : "Ayuda",
+    "Appearance and accessibility" : "Apariencia y accesibilidad",
     "Apps" : "Aplicaciones",
+    "Personal settings" : "Configuración personal",
+    "Administration settings" : "Configuración de administración",
     "Settings" : "Ajustes",
     "Log out" : "Cerrar sesión",
     "Users" : "Usuarios",
     "Email" : "Correo electrónico",
+    "Mail %s" : "Correo %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Ver %s en Fediverse",
     "Phone" : "Teléfono fijo",
+    "Call %s" : "Llamar a %s",
     "Twitter" : "Twitter",
+    "View %s on Twitter" : "Ver %s en Twitter",
     "Website" : "Sitio web",
+    "Visit %s" : "Visitar %s",
     "Address" : "Dirección",
     "Profile picture" : "Foto de perfil",
     "About" : "Acerca de",
-    "Full name" : "Nombre completo",
-    "Unknown user" : "Ususario desconocido",
+    "Display name" : "Nombre para mostrar",
+    "Headline" : "Título",
+    "Organisation" : "Organización",
+    "Role" : "Rol",
     "Additional settings" : "Configuraciones adicionales",
+    "Enter the database name for %s" : "Introduce el nombre de la base de datos para %s",
+    "You cannot use dots in the database name %s" : "No se pueden utilizar puntos en el nombre de la base de datos %s",
     "You need to enter details of an existing account." : "Necesitas ingresar los detalles de una cuenta existente.",
     "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
-    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "El Usuario y/o Contraseña de PostgreSQL inválido(s)",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Úsalo bajo tu propio riesgo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, por favor cosidera usar en su lugar un servidor GNU/Linux.",
-    "Set an admin username." : "Establecer un Usuario administrador",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor elimina el ajuste open_basedir de tu archivo php.ini o cambia a PHP de 64 bits. ",
     "Set an admin password." : "Establecer la contraseña del administrador.",
+    "Cannot create or write into the data directory %s" : "No se puede crear ni escribir en el directorio de datos %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartió »%2$s« contigo y quiere añadir:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartió »%2$s« contigo y quiere añadir",
+    "»%s« added a note to a file shared with you" : "»%s« añadió una nota a un archivo compartido contigo",
     "Open »%s«" : "Abrir »%s«",
+    "%1$s via %2$s" : "%1$s a través de %2$s",
     "You are not allowed to share %s" : "No tienes permitido compartir %s",
     "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
+    "Files cannot be shared with delete permissions" : "No se pueden compartir archivos con permisos de eliminación",
+    "Files cannot be shared with create permissions" : "No se pueden compartir archivos con permisos de creación",
     "Expiration date is in the past" : "La fecha de expiración se encuentra en el pasado",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No se puede establecer una fecha de caducidad más de %n día en el futuro","No se puede establecer una fecha de caducidad más de %n días en el futuro","No se puede establecer una fecha de caducidad más de %n días en el futuro"],
+    "Sharing is only allowed with group members" : "Solo se permite compartir con miembros del grupo",
+    "%1$s shared »%2$s« with you" : "%1$s compartió »%2$s« contigo",
+    "%1$s shared »%2$s« with you." : "%1$s compartió »%2$s« contigo.",
     "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
     "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "No se creó el usuario porque se ha alcanzado el límite de usuarios. Consulta tus notificaciones para obtener más información.",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
     "Sunday" : "Domingo",
     "Monday" : "Lunes",
@@ -134,60 +190,78 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Dic.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
-    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
-    "The username is already being used" : "Ese usuario ya está en uso",
-    "Could not create user" : "No fue posible crear el usuario",
-    "User disabled" : "Usuario deshabilitado",
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "No se puede instalar la aplicación \"%1$s\" porque no se cumplen las siguientes dependencias: %2$s",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
     "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
+    "Cannot download file" : "No se puede descargar el archivo",
     "Application is not enabled" : "La aplicación está deshabilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "La ficha ha expirado. Por favor recarga la página.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "No cuentas con controladores de base de datos (sqlite, mysql o postgresql) instalados. ",
+    "Cannot write into \"config\" directory." : "No se puede escribir en el directorio \"config\".",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Generalmente, esto se puede solucionar otorgando permisos de escritura al servidor web en el directorio de configuración. Consulta %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, si prefieres mantener el archivo config.php como de solo lectura, establece la opción \"config_is_read_only\" en true. Consulta %s",
+    "Cannot write into \"apps\" directory." : "No se puede escribir en el directorio \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Generalmente, esto se puede solucionar otorgando permisos de escritura al servidor web en el directorio de aplicaciones o deshabilitando la tienda de aplicaciones en el archivo de configuración.",
+    "Cannot create \"data\" directory." : "No se puede crear el directorio \"data\".",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Generalmente, esto se puede solucionar otorgando permisos de escritura al servidor web en el directorio raíz. Consulta %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Los permisos generalmente se pueden solucionar otorgando permisos de escritura al servidor web en el directorio raíz. Consulta %s.",
+    "Your data directory is not writable." : "El directorio de datos no es escribible.",
+    "Setting locale to %s failed." : "Error al establecer la configuración regional en %s.",
+    "Please install one of these locales on your system and restart your web server." : "Instala una de estas configuraciones regionales en tu sistema y reinicia tu servidor web.",
     "PHP module %s not installed." : "El módulo de PHP %s no está instalado. ",
     "Please ask your server administrator to install the module." : "Por favor solicita a tu adminsitrador la instalación del módulo. ",
     "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s está instalado. ",
-    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, por favor actualiza la versión de su libxml2 y reinicia tu servidor web. ",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado como <code>%s</code> en lugar del valor esperado <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para solucionar este problema, establece <code>mbstring.func_overload</code> como <code>0</code> en tu archivo php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor solicita al administrador reiniciar el servidor web. ",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
+    "The required %s config variable is not configured in the config.php file." : "No se ha configurado la variable de configuración %s requerida en el archivo config.php.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Pide a tu administrador del servidor que verifique la configuración de Nextcloud.",
+    "Your data directory must be an absolute path." : "Tu directorio de datos debe ser una ruta absoluta.",
+    "Check the value of \"datadirectory\" in your configuration." : "Verifica el valor de \"datadirectory\" en tu configuración.",
+    "Your data directory is invalid." : "Tu directorio de datos no es válido.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegurate de que exista una archivo llamado \".ocdata\" en la raíz del directorio de datos. ",
+    "Action \"%s\" not supported or implemented." : "La acción \"%s\" no está soportada o no está implementada.",
+    "Authentication failed, wrong token or provider ID given" : "Falló la autenticación, se proporcionó un token o un ID de proveedor incorrecto",
+    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar la solicitud. Parámetros faltantes: \"%s\"",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "El ID \"%1$s\" ya está en uso por el proveedor de federación de la nube \"%2$s\"",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "No existe un Proveedor de Federación de la Nube con el ID: \"%s\".",
     "Could not obtain lock type %d on \"%s\"." : "No fue posible obtener el tipo de bloqueo %d en \"%s\". ",
     "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
     "Storage incomplete configuration. %s" : "Configuración incompleta del almacenamiento. %s",
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
-    "%s enter the database username and name." : "%s ingresa el usuario y nombre de la base de datos",
-    "%s enter the database username." : "%s ingresa el nombre de usuario de la base de datos.",
-    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
-    "%s you may not use dots in the database name" : "%s no puedes utilizar puntos en el nombre de la base de datos",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor elimina el ajuste open_basedir de tu archivo php.ini o cambia a PHP de 64 bits. ",
-    "Cannot write into \"config\" directory" : "No fue posible escribir en el directorio \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio config. Por favor ve %s",
-    "Cannot write into \"apps\" directory" : "No fue posible escribir en el directorio \"apps\"",
-    "Cannot create \"data\" directory" : "No fue posible crear el directorio \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Por lo general los permisos se pueden corregir al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s.",
-    "Setting locale to %s failed" : "Se presentó una falla al establecer la regionalización a  %s",
-    "Please install one of these locales on your system and restart your webserver." : "Por favor instala uno de las siguientes configuraciones locales en tu sistema y reinicia tu servidor web",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está establecido como \"%s\" en lugar del valor esperado de \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corregir este tema, establece <code>mbstring.func_overload</code> a <code>0</code> en tu archivo php.ini",
-    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
-    "Please upgrade your database version" : "Por favor actualiza tu versión de la base de datos",
-    "Your data directory is readable by other users" : "Tu direcctorio data puede ser leído por otros usuarios",
-    "Your data directory must be an absolute path" : "Tu directorio data debe ser una ruta absoluta",
-    "Check the value of \"datadirectory\" in your configuration" : "Verifica el valor de \"datadirectory\" en tu configuración",
-    "Your data directory is invalid" : "Tu directorio de datos es inválido"
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "El usuario que ha iniciado sesión debe ser un administrador, un subadministrador o tener permisos especiales para acceder a esta configuración.",
+    "Logged in user must be an admin or sub admin" : "El usuario que ha iniciado sesión debe ser un administrador o un subadministrador.",
+    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
+    "Help" : "Ayuda",
+    "Unknown user" : "Ususario desconocido",
+    "Enter the database username and name for %s" : "Introduce el nombre de usuario y el nombre de la base de datos para %s",
+    "Enter the database username for %s" : "Introduce el nombre de usuario de la base de datos para %s",
+    "MySQL username and/or password not valid" : "Nombre de usuario y/o contraseña de MySQL no válidos",
+    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
+    "PostgreSQL username and/or password not valid" : "El Usuario y/o Contraseña de PostgreSQL inválido(s)",
+    "Set an admin username." : "Establecer un Usuario administrador",
+    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
+    "The username is already being used" : "Ese usuario ya está en uso",
+    "Could not create user" : "No fue posible crear el usuario",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Solo se permiten los siguientes caracteres en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", espacios y \"_.@-'\"",
+    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
+    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
+    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
+    "Username is invalid because files already exist for this user" : "El nombre de usuario no es válido porque ya existen archivos para este usuario",
+    "User disabled" : "Usuario deshabilitado",
+    "PostgreSQL >= 9 required." : "Se requiere PostgreSQL >= 9.",
+    "Please upgrade your database version." : "Actualiza la versión de tu base de datos.",
+    "Your data directory is readable by other users." : "Tu directorio de datos es legible por otros usuarios.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
