@@ -5,9 +5,10 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára a konfigurációs könyvtáron.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "De ha szeretné, hogy a config.php fájlja csak olvasható legyen, akkor állítsa benne igazra a „config_is_read_only” beállítást.",
     "See %s" : "Lásd %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "A(z) %1$s alkalmazás fájljait helytelenül cserélték le. Ellenőrizze, hogy a verzió kompatibilis-e a kiszolgálóval.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "A(z) %1$s alkalmazás nincs jelen, vagy a verziója nem kompatibilis ezzel a kiszolgálóval. Ellenőrizze az alkalmazástárat.",
     "Sample configuration detected" : "Példabeállítások észlelve",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Úgy tűnik, hogy a példakonfigurációt másolta le. Ez működésképtelenné teheti a telepítést, és nem támogatott. Olvassa el a dokumentációt, mielőtt módosításokat véget a config.php fájlban.",
+    "The page could not be found on the server." : "Az oldal nem található a kiszolgálón.",
     "%s email verification" : "%s e-mail ellenőrzés",
     "Email verification" : "E-mail ellenőrzés",
     "Click the following button to confirm your email." : "Kattintson a következő gombra, hogy megerősítse az e-mail-címét.",
@@ -35,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "A következő platformok támogatottak: %s",
     "Server version %s or higher is required." : "%s vagy újabb kiszolgálóverzió szükséges.",
     "Server version %s or lower is required." : "%s vagy régebbi kiszolgálóverzió szükséges.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazdának kell lennie, vagy speciális hozzáféréssel kell rendelkeznie ehhez a beállításhoz",
-    "Logged in user must be an admin or sub admin" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazgának kell lennie",
-    "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
     "Wiping of device %s has started" : "A(z) %s eszköz törlése megkezdődött",
     "Wiping of device »%s« has started" : "A(z) „%s” eszköz törlése megkezdődött",
     "»%s« started remote wipe" : "„%s” elindította a távoli törlést",
@@ -54,7 +52,9 @@ OC.L10N.register(
     "Unknown filetype" : "Ismeretlen fájltípus",
     "Invalid image" : "Érvénytelen kép",
     "Avatar image is not square" : "A profilkép nem négyzetes.",
+    "Files" : "Fájlok",
     "View profile" : "Profil megtekintése",
+    "Local time: %s" : "Helyi idő: %s",
     "today" : "ma",
     "tomorrow" : "holnap",
     "yesterday" : "tegnap",
@@ -89,7 +89,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "A(z) „%s” alkalmazást nem lehet telepíteni, mert nem kompatibilis ezzel a kiszolgálóverzióval.",
     "__language_name__" : "Magyar",
     "This is an automatically sent email, please do not reply." : "Ez egy automatikusan küldött levél, ne válaszoljon rá.",
-    "Help" : "Súgó",
     "Appearance and accessibility" : "Megjelenés és akadálymentesítés",
     "Apps" : "Alkalmazások",
     "Personal settings" : "Személyes beállítások",
@@ -99,6 +98,8 @@ OC.L10N.register(
     "Users" : "Felhasználók",
     "Email" : "E-mail",
     "Mail %s" : "Levél küldése ide: %s",
+    "Fediverse" : "Födiverzum",
+    "View %s on the fediverse" : "A(z) %s megtekintése a födiverzumban",
     "Phone" : "Telefon",
     "Call %s" : "%s hívása",
     "Twitter" : "Twitter",
@@ -108,20 +109,19 @@ OC.L10N.register(
     "Address" : "Cím",
     "Profile picture" : "Profilkép",
     "About" : "Névjegy",
-    "Full name" : "Teljes név",
-    "Headline" : "Főcím",
+    "Display name" : "Megjelenítendő név",
+    "Headline" : "Címsor",
     "Organisation" : "Szervezet",
     "Role" : "Szerepkör",
-    "Unknown user" : "Ismeretlen felhasználó",
     "Additional settings" : "További beállítások",
-    "MySQL username and/or password not valid" : "A MySQL felhasználónév vagy jelszó érvénytelen",
+    "Enter the database name for %s" : "Adja meg a %s adatbázisának nevét",
+    "You cannot use dots in the database name %s" : "A(z) %s adatbázisnév nem tartalmazhat pontot",
     "You need to enter details of an existing account." : "Egy már létező fiók adatait kell megadnia.",
     "Oracle connection could not be established" : "Az Oracle kapcsolat nem hozható létre",
-    "Oracle username and/or password not valid" : "Az Oracle felhasználónév vagy jelszó érvénytelen",
-    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név vagy jelszó érvénytelen",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott, és a %s nem lesz teljesen működőképes. Csak saját felelősségre használja.",
     "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux kiszolgálót használni.",
-    "Set an admin username." : "Állítson be egy rendszergazdai felhasználónevet.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Úgy tűnik, hogy ez a %s példány 32 bites PHP környezetben fut, és az open_basedir be lett állítva a php.ini fájlban. Ez 4 GB-nál nagyobb fájlok esetén problémákat okozhat, így erősen ellenjavallott.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Távolítsa el az open_basedir beállítást a php.ini fájlból, vagy váltson 64 bites PHP-ra.",
     "Set an admin password." : "Állítson be egy rendszergazdai jelszót.",
     "Cannot create or write into the data directory %s" : "Nem létre létrehozni vagy beleírni a(z) %s adatkönyvtárba",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A(z) %s megosztási alrendszernek meg kell valósítania az OCP\\Share_Backend interfészt",
@@ -139,11 +139,12 @@ OC.L10N.register(
     "Expiration date is in the past" : "A lejárati dátum már elmúlt",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nem állítható be %n napnál távolabbi lejárati dátum","Nem állítható be %n napnál távolabbi lejárati dátum"],
     "Sharing is only allowed with group members" : "A megosztás csak a csoport tagjaival engedélyezett",
-    "Sharing %s failed, because this item is already shared with user %s" : "A(z) %s megosztása nem sikerült, mert ez az elem már meg van osztva a(z) %s felhasználóval",
     "%1$s shared »%2$s« with you" : "%1$s megosztotta Önnel: „%2$s”",
     "%1$s shared »%2$s« with you." : "%1$s megosztotta Önnel: „%2$s”.",
     "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
     "The requested share does not exist anymore" : "A kért megosztás már nem létezik",
+    "The requested share comes from a disabled user" : "A kért megosztás letiltott felhasználótól származik",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "A felhasználó nem jött létre, mert elérte a felhasználókorlátot. Nézze meg az értesítéseit, hogy többet tudjon meg.",
     "Could not find category \"%s\"" : "Ez a kategória nem található: \"%s\"",
     "Sunday" : "Vasárnap",
     "Monday" : "Hétfő",
@@ -190,15 +191,7 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek engedélyezettek: „a-z”, „A-Z”, „0-9”, és „_.@-'”",
-    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
-    "Username contains whitespace at the beginning or at the end" : "A felhasználónév szóközt tartalmaz az elején vagy a végén",
-    "Username must not consist of dots only" : "A felhasználónév nem állhat csak pontokból",
-    "Username is invalid because files already exist for this user" : "A felhasználónév érvénytelen, mert már vannak fájlok ehhez a felhasználóhoz",
     "A valid password must be provided" : "Érvényes jelszót kell megadnia",
-    "The username is already being used" : "Ez a felhasználónév már foglalt",
-    "Could not create user" : "Nem sikerült létrehozni a felhasználót",
-    "User disabled" : "Felhasználó letiltva",
     "Login canceled by app" : "Bejelentkezés megszakítva az alkalmazás által",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "A(z) „%1$s” alkalmazást nem lehet telepíteni, mert a következő függőségek nem teljesülnek: %2$s",
     "a safe home for all your data" : "egy biztonságos hely az adataidnak",
@@ -225,18 +218,12 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make Nextcloud run again" : "A beállítás a php.ini fájlban történő módosításai után újra fog futni a Nexcloud",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Az <code>mbstring.func_overload</code> a várt <code>0</code> érték helyett erre van állítva: <code>%s</code>.",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "A probléma javításához állítsa <code>0</code>-ra az <code>mbstring.func_overload</code> értékét a php.ini-ben.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Legalább libxml2 2.7.0 szükséges. Jelenleg telepített: %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "A probléma javításához frissítse a libxml2 verziót, és indítsa újra a webkiszolgálót.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Úgy tűnik, hogy a PHP úgy van beállítva, hogy eltávolítja programok belsejében elhelyezett szövegblokkokat. Emiatt a rendszer több alapvető fontosságú eleme működésképtelen lesz.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár, mint például a Zend, az OPcache vagy az eAccelererator okozza.",
     "PHP modules have been installed, but they are still listed as missing?" : "A PHP modulok telepítve vannak, de a listában mégsem szerepelnek?",
     "Please ask your server administrator to restart the web server." : "Kérje meg a rendszergazdát, hogy indítsa újra a webkiszolgálót.",
     "The required %s config variable is not configured in the config.php file." : "A szükséges %s konfigurációs változó nincs beállítva a config.php fájlban.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Kérje meg a rendszergazdát, hogy ellenőrizze a Nextcloud konfigurációját.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 szükséges.",
-    "Please upgrade your database version." : "Frissítse az adatbázis verzióját.",
-    "Your data directory is readable by other users." : "Az adatkönyvtára más felhasználók által is olvasható.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználók ne listázhassák.",
     "Your data directory must be an absolute path." : "Az adatkönyvtárnak abszolút útvonalnak kell lennie",
     "Check the value of \"datadirectory\" in your configuration." : "Ellenőrizze a „datadirectory” értékét a konfigurációban.",
     "Your data directory is invalid." : "Az adatkönyvtár érvénytelen.",
@@ -252,31 +239,38 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tároló kapcsolódási hiba. %s",
     "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
     "Storage connection timeout. %s" : "Időtúllépés a tárolókapcsolatban. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Ez általában úgy javítható, hogy a webkiszolgálónak írási hozzáférést biztosít a konfigurációs könyvtárhoz.",
-    "%s enter the database username and name." : "%s adja meg az adatbázis nevét és a felhasználónevet.",
-    "%s enter the database username." : "%s adja meg az adatbázishoz tartozó felhasználónevet.",
-    "%s enter the database name." : "%s adja meg az adatbázis nevét.",
-    "%s you may not use dots in the database name" : "%s az adatbázis neve nem tartalmazhat pontot",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Úgy tűnik, hogy ez a %s példány 32 bites PHP környezetben fut, és az open_basedir be lett állítva a php.ini fájlban. Ez 4 GB-nál nagyobb fájlok esetén problémákat okozhat, így erősen ellenjavallott.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Távolítsa el az open_basedir beállítást a php.ini fájlból, vagy váltson 64 bites PHP-ra.",
-    "The user limit has been reached and the user was not created." : "Elérte a felhasználói korlátot, és a felhasználó nem jött létre.",
-    "Cannot read file" : "A fájl nem olvasható",
-    "Cannot write into \"config\" directory" : "A „config” könyvtár nem írható",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ez általában úgy javítható, hogy a webkiszolgálónak írási hozzáférést biztosít a konfigurációs könyvtárhoz. Lásd: %s.",
-    "Cannot write into \"apps\" directory" : "Az „apps” könyvtár nem írható",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára az apps könyvtáron, vagy letiltja az alkalmazástárt a konfigurációs fájlban.",
-    "Cannot create \"data\" directory" : "A „data” könyvtár nem hozható létre",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ez általában úgy javítható, hogy a webkiszolgálónak írási hozzáférést biztosít a gyökérkönyvtárhoz. Lásd: %s.",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Az engedélyek általában úgy javíthatók, hogy írási jogosultságot ad a webkiszolgáló számára a gyökérkönyvtáron. Lásd %s.",
-    "Setting locale to %s failed" : "A területi beállítás „%s” értékre állítása sikertelen",
-    "Please install one of these locales on your system and restart your webserver." : "Telepítse a következő területi beállítások valamelyikét a rendszeren, és indítsa újra a webkiszolgálót.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "Az mbstring.func_overload a várt 0 érték helyett erre van állítva: „%s”",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "A probléma javításához állítsa <code>0</code>-ra az <code>mbstring.func_overload</code> értékét a php.ini-ben",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 szükséges",
-    "Please upgrade your database version" : "Frissítse az adatbázis verzióját",
-    "Your data directory is readable by other users" : "Az adatkönyvtára más felhasználók által is olvasható",
-    "Your data directory must be an absolute path" : "Az adatkönyvtárnak abszolút útvonalnak kell lennie",
-    "Check the value of \"datadirectory\" in your configuration" : "Ellenőrizze a „datadirectory” értékét a konfigurációban",
-    "Your data directory is invalid" : "Az adatkönyvtár érvénytelen"
+    "Free prompt" : "Szabad prompt",
+    "Runs an arbitrary prompt through the language model." : "Tetszőleges promptot futtat a nyelvi modellen.",
+    "Generate headline" : "Címsor előállítása",
+    "Generates a possible headline for a text." : "Egy lehetséges címsort állít elő egy szöveghez.",
+    "Summarize" : "Összesítés",
+    "Summarizes text by reducing its length without losing key information." : "Összesíti a szöveget a hosszúság csökkentésével anélkül, hogy a kulcsinformációk elvesznének.",
+    "Extract topics" : "Témák kinyerése",
+    "Extracts topics from a text and outputs them separated by commas." : "Kinyeri a témákat a szövegből, és vesszőkkel elválasztva megjeleníti.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazdának kell lennie, vagy speciális hozzáféréssel kell rendelkeznie ehhez a beállításhoz",
+    "Logged in user must be an admin or sub admin" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazgának kell lennie",
+    "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
+    "Help" : "Súgó",
+    "Unknown user" : "Ismeretlen felhasználó",
+    "Enter the database username and name for %s" : "Adja meg a %s adatbázisának nevét és a hozzá tartozó felhasználónevet",
+    "Enter the database username for %s" : "Adja meg a %s adatbázisához tartozó felhasználónevet",
+    "MySQL username and/or password not valid" : "A MySQL felhasználónév vagy jelszó érvénytelen",
+    "Oracle username and/or password not valid" : "Az Oracle felhasználónév vagy jelszó érvénytelen",
+    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név vagy jelszó érvénytelen",
+    "Set an admin username." : "Állítson be egy rendszergazdai felhasználónevet.",
+    "Sharing %s failed, because this item is already shared with user %s" : "A(z) %s megosztása nem sikerült, mert ez az elem már meg van osztva a(z) %s felhasználóval",
+    "The username is already being used" : "Ez a felhasználónév már foglalt",
+    "Could not create user" : "Nem sikerült létrehozni a felhasználót",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek engedélyezettek: „a-z”, „A-Z”, „0-9”, szóköz és „_.@-'”",
+    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
+    "Username contains whitespace at the beginning or at the end" : "A felhasználónév szóközt tartalmaz az elején vagy a végén",
+    "Username must not consist of dots only" : "A felhasználónév nem állhat csak pontokból",
+    "Username is invalid because files already exist for this user" : "A felhasználónév érvénytelen, mert már vannak fájlok ehhez a felhasználóhoz",
+    "User disabled" : "Felhasználó letiltva",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 szükséges.",
+    "Please upgrade your database version." : "Frissítse az adatbázis verzióját.",
+    "Your data directory is readable by other users." : "Az adatkönyvtára más felhasználók által is olvasható.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználók ne listázhassák."
 },
 "nplurals=2; plural=(n != 1);");
